| consistent-doc | R Documentation |
Helper for consistent documentation
cdm |
A |
omopTableName |
A character vector of the names of the tables to
summarise in the cdm object. Run |
ageGroup |
A list of age groups to stratify the results by. Each element
represents a specific age range. You can give them specific names, e.g.
|
sex |
Logical; whether to stratify results by sex ( |
facet |
Columns to face by. Formula format can be provided. See possible
columns to face by with: |
colour |
Columns to colour by. See possible columns to colour by with:
|
interval |
Time interval to stratify by. It can either be "years", "quarters", "months" or "overall". |
sample |
Either an integer or a character string.
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.