View source: R/databaseCharacteristics.R
| databaseCharacteristics | R Documentation |
Summarise Database Characteristics for OMOP CDM
databaseCharacteristics(
cdm,
omopTableName = c("visit_occurrence", "visit_detail", "condition_occurrence",
"drug_exposure", "procedure_occurrence", "device_exposure", "measurement",
"observation", "death"),
sample = NULL,
sex = FALSE,
ageGroup = NULL,
dateRange = NULL,
interval = "overall",
conceptIdCounts = FALSE,
...
)
cdm |
A |
omopTableName |
A character vector of the names of the tables to
summarise in the cdm object. Run |
sample |
Either an integer or a character string.
|
sex |
Logical; whether to stratify results by sex ( |
ageGroup |
A list of age groups to stratify the results by. Each element
represents a specific age range. You can give them specific names, e.g.
|
dateRange |
A vector of two dates defining the desired study period.
Only the |
interval |
Time interval to stratify by. It can either be "years", "quarters", "months" or "overall". |
conceptIdCounts |
Logical; whether to summarise concept ID counts
( |
... |
additional arguments passed to the OmopSketch functions that are used internally. |
A summarised_result object with the results.
## Not run:
library(OmopSketch)
library(omock)
library(dplyr)
library(here)
cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
result <- databaseCharacteristics(
cdm = cdm,
sample = 100,
omopTableName = c("drug_exposure", "condition_occurrence"),
sex = TRUE,
ageGroup = list(c(0, 50), c(51, 100)),
interval = "years",
conceptIdCounts = FALSE
)
result |>
glimpse()
shinyCharacteristics(result = result, directory = here())
cdmDisconnect(cdm = cdm)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.