dateRange-startDate: Helper for consistent documentation of 'dateRange'.

dateRange-startDateR Documentation

Helper for consistent documentation of dateRange.

Description

Helper for consistent documentation of dateRange.

Arguments

dateRange

A vector of two dates defining the desired study period. Only the start_date column of the OMOP table is checked to ensure it falls within this range. If dateRange is NULL, no restriction is applied.


OmopSketch documentation built on Aug. 27, 2026, 5:07 p.m.