View source: R/summariseClinicalRecords.R
| summariseClinicalRecords | R Documentation |
You will obtain information related to the number of records, number of subjects, whether the records are in observation, number of present domains, number of present concepts, missing data and inconsistencies in start date and end date.
summariseClinicalRecords(
cdm,
omopTableName,
recordsPerPerson = c("mean", "sd", "median", "q25", "q75", "min", "max"),
conceptSummary = TRUE,
missingData = TRUE,
quality = TRUE,
sex = FALSE,
ageGroup = NULL,
dateRange = NULL,
inObservation = lifecycle::deprecated(),
standardConcept = lifecycle::deprecated(),
sourceVocabulary = lifecycle::deprecated(),
domainId = lifecycle::deprecated(),
typeConcept = lifecycle::deprecated()
)
cdm |
A |
omopTableName |
A character vector of the names of the tables to
summarise in the cdm object. Run |
recordsPerPerson |
Generates summary statistics for the number of records per person. Set to NULL if no summary statistics are required. |
conceptSummary |
Logical. If
|
missingData |
Logical. If |
quality |
Logical. If
|
sex |
Logical; whether to stratify results by sex ( |
ageGroup |
A list of age groups to stratify the results by. Each element
represents a specific age range. You can give them specific names, e.g.
|
dateRange |
A vector of two dates defining the desired study period.
Only the |
inObservation |
Deprecated. Use |
standardConcept |
Deprecated. Use |
sourceVocabulary |
Deprecated. Use |
domainId |
Deprecated. Use |
typeConcept |
Deprecated. Use |
A summarised_result object with the results.
library(OmopSketch)
library(omock)
cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
result <- summariseClinicalRecords(
cdm = cdm,
omopTableName = "condition_occurrence",
recordsPerPerson = c("mean", "sd"),
quality = TRUE,
conceptSummary = TRUE,
missingData = TRUE
)
tableClinicalRecords(result = result)
cdmDisconnect(cdm = cdm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.