View source: R/summariseConceptIdCounts.R
| summariseConceptIdCounts | R Documentation |
Only concepts recorded during observation period are counted.
summariseConceptIdCounts(
cdm,
omopTableName,
countBy = "record",
interval = "overall",
sex = FALSE,
ageGroup = NULL,
inObservation = FALSE,
sample = NULL,
dateRange = NULL,
year = lifecycle::deprecated()
)
cdm |
A |
omopTableName |
A character vector of the names of the tables to
summarise in the cdm object. Run |
countBy |
Either "record" for record-level counts or "person" for person-level counts. |
interval |
Time interval to stratify by. It can either be "years", "quarters", "months" or "overall". |
sex |
Logical; whether to stratify results by sex ( |
ageGroup |
A list of age groups to stratify the results by. Each element
represents a specific age range. You can give them specific names, e.g.
|
inObservation |
Logical. If |
sample |
Either an integer or a character string.
|
dateRange |
A vector of two dates defining the desired study period.
Only the |
year |
deprecated. |
A summarised_result object with the results.
library(OmopSketch)
library(omock)
cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
result <- summariseConceptIdCounts(
cdm = cdm,
omopTableName = "condition_occurrence",
countBy = c("record", "person"),
sex = TRUE
)
tableConceptIdCounts(result = result)
cdmDisconnect(cdm = cdm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.