View source: R/summariseConceptSetCounts.R
| summariseConceptSetCounts | R Documentation |
Only concepts recorded during observation period are counted.
summariseConceptSetCounts(
cdm,
conceptSet,
countBy = c("record", "person"),
concept = TRUE,
interval = "overall",
sex = FALSE,
ageGroup = NULL,
dateRange = NULL
)
cdm |
A |
conceptSet |
List of concept IDs to summarise. |
countBy |
Either "record" for record-level counts or "person" for person-level counts |
concept |
TRUE or FALSE. If TRUE code use will be summarised by concept. |
interval |
Time interval to stratify by. It can either be "years", "quarters", "months" or "overall". |
sex |
Logical; whether to stratify results by sex ( |
ageGroup |
A list of age groups to stratify the results by. Each element
represents a specific age range. You can give them specific names, e.g.
|
dateRange |
A vector of two dates defining the desired study period.
Only the |
A summarised_result object with the results.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.