View source: R/summariseMissingData.R
| summariseMissingData | R Documentation |
Summarise missing data in omop tables
summariseMissingData(
cdm,
omopTableName,
col = NULL,
sex = FALSE,
interval = "overall",
ageGroup = NULL,
sample = 1e+05,
dateRange = NULL,
year = lifecycle::deprecated()
)
cdm |
A |
omopTableName |
A character vector of the names of the tables to
summarise in the cdm object. Run |
col |
A character vector of column names to check for missing values.
If |
sex |
Logical; whether to stratify results by sex ( |
interval |
Time interval to stratify by. It can either be "years", "quarters", "months" or "overall". |
ageGroup |
A list of age groups to stratify the results by. Each element
represents a specific age range. You can give them specific names, e.g.
|
sample |
Either an integer or a character string.
|
dateRange |
A vector of two dates defining the desired study period.
Only the |
year |
deprecated |
A summarised_result object with the results.
library(OmopSketch)
library(omock)
cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
result <- summariseMissingData(
cdm = cdm,
omopTableName = c("condition_occurrence", "visit_occurrence"),
sample = 10000
)
tableMissingData(result = result)
cdmDisconnect(cdm = cdm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.