View source: R/summariseObservationPeriod.R
| summariseObservationPeriod | R Documentation |
Summarise the observation period table getting some overall statistics in a summarised_result object
summariseObservationPeriod(
cdm,
estimates = c("mean", "sd", "min", "q05", "q25", "median", "q75", "q95", "max",
"density"),
missingData = TRUE,
quality = TRUE,
byOrdinal = TRUE,
ageGroup = NULL,
sex = FALSE,
dateRange = NULL,
observationPeriod = lifecycle::deprecated()
)
cdm |
A |
estimates |
Estimates to summarise the variables of interest (
|
missingData |
Logical. If |
quality |
Logical. If
|
byOrdinal |
Boolean variable. Whether to stratify by the ordinal observation period (e.g., 1st, 2nd, etc.) (TRUE) or simply analyze overall data (FALSE) |
ageGroup |
A list of age groups to stratify the results by. Each element
represents a specific age range. You can give them specific names, e.g.
|
sex |
Logical; whether to stratify results by sex ( |
dateRange |
A vector of two dates defining the desired study period.
Only the |
observationPeriod |
deprecated. |
A summarised_result object with the results.
library(OmopSketch)
library(dplyr, warn.conflicts = FALSE)
library(omock)
cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
result <- summariseObservationPeriod(cdm = cdm)
tableObservationPeriod(result = result)
plotObservationPeriod(
result = result,
variableName = "Duration in days",
plotType = "boxplot"
)
cdmDisconnect(cdm = cdm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.