summariseOmopSnapshot: Summarise a cdm_reference object creating a snapshot with the...

View source: R/summariseOmopSnapshot.R

summariseOmopSnapshotR Documentation

Summarise a cdm_reference object creating a snapshot with the metadata of the cdm_reference object

Description

Summarise a cdm_reference object creating a snapshot with the metadata of the cdm_reference object

Usage

summariseOmopSnapshot(cdm)

Arguments

cdm

A cdm_reference object. Use CDMConnector to create a reference to a database or omock to create a reference to synthetic data.

Value

A summarised_result object with the results.

Examples


library(OmopSketch)
library(omock)

cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")

result <- summariseOmopSnapshot(cdm = cdm)

tableOmopSnapshot(result = result)

cdmDisconnect(cdm = cdm)



OmopSketch documentation built on Aug. 27, 2026, 5:07 p.m.