View source: R/tableMissingData.R
| tableMissingData | R Documentation |
Create a visual table from a summariseMissingData() result
tableMissingData(
result,
header = "cdm_name",
hide = c("variable_name", omopgenerics::settingsColumns(result)),
groupColumn = c("omop_table", omopgenerics::strataColumns(result)),
type = NULL,
style = NULL
)
result |
A summarised_result object (output of
|
header |
A vector specifying the elements to include in the header. The order of elements matters, with the first being the topmost header. |
hide |
Columns to drop from the output table. |
groupColumn |
Columns to use as group labels, to see options use visOmopResults::tableColumns(result). |
type |
Character string specifying the desired output table format. See
|
style |
Defines the visual formatting of the table. This argument can be provided in one of the following ways:
If |
A formatted table visualisation.
library(OmopSketch)
library(omock)
cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
result <- summariseMissingData(
cdm = cdm,
omopTableName = c("condition_occurrence", "visit_occurrence")
)
tableMissingData(result = result)
cdmDisconnect(cdm = cdm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.