View source: R/tablePerson.R View source: R/summarisePerson.R
| tablePerson | R Documentation |
summarisePerson() into a tableVisualise the results of summarisePerson() into a table
Visualise the output of summarisePerson()
tablePerson(
result,
header = "cdm_name",
hide = omopgenerics::settingsColumns(result),
groupColumn = character(),
type = NULL,
style = NULL
)
tablePerson(
result,
header = "cdm_name",
hide = omopgenerics::settingsColumns(result),
groupColumn = character(),
type = NULL,
style = NULL
)
result |
A summarised_result object (output of |
header |
A vector specifying the elements to include in the header. The order of elements matters, with the first being the topmost header. |
hide |
Columns to drop from the output table. |
groupColumn |
Columns to use as group labels, to see options use visOmopResults::tableColumns(result). |
type |
Character string specifying the desired output table format. See
|
style |
Defines the visual formatting of the table. This argument can be provided in one of the following ways:
If |
A formatted table visualisation.
A formatted table visualisation.
library(OmopSketch)
library(omock)
cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
result <- summarisePerson(cdm = cdm)
tablePerson(result = result)
library(OmopSketch)
library(omock)
cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
result <- summarisePerson(cdm = cdm)
tablePerson(result = result)
cdmDisconnect(cdm = cdm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.