| tableTrend | R Documentation |
Create a visual table from a summariseTrend() result
tableTrend(
result,
header = "cdm_name",
hide = "variable_level",
groupColumn = c("type", "omop_table"),
type = NULL,
style = NULL
)
result |
A summarised_result object (output of |
header |
A vector specifying the elements to include in the header. The order of elements matters, with the first being the topmost header. |
hide |
Columns to drop from the output table. |
groupColumn |
Columns to use as group labels, to see options use visOmopResults::tableColumns(result). |
type |
Type of formatting output table between |
style |
Defines the visual formatting of the table. This argument can be provided in one of the following ways:
If |
A formatted table visualisation.
library(OmopSketch)
library(dplyr, warn.conflicts = FALSE)
library(omock)
cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
result <- summariseTrend(
cdm = cdm,
episode = "observation_period",
event = c("drug_exposure", "condition_occurrence"),
interval = "years",
ageGroup = list("<=20" = c(0, 20), ">20" = c(21, Inf)),
sex = TRUE
)
tableTrend(result = result)
cdmDisconnect(cdm = cdm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.