View source: R/shinyCharacteristics.R
| shinyCharacteristics | R Documentation |
databaseCharacteristics() functionGenerate an interactive Shiny application that visualises the results
obtained from the databaseCharacteristics() function
shinyCharacteristics(
result,
directory,
background = TRUE,
title = "Database characterisation",
logo = "ohdsi",
theme = NULL
)
result |
A summarised_result object (output of
|
directory |
A character string specifying the directory where the application will be saved. |
background |
Background panel for the Shiny app.
|
title |
Title of the shiny. Default is "Characterisation". |
logo |
Name of a logo or path to a logo. If NULL no logo is included. Only svg format allowed for the moment. |
theme |
A character string specifying the theme for the Shiny application. It can be any of the OmopViewer supported themes. |
This function invisibly returns NULL and generates a static Shiny app in the specified directory.
## Not run:
library(OmopSketch)
library(omock)
library(here)
cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
res <- databaseCharacteristics(cdm = cdm)
shinyCharacteristics(result = res, directory = here())
cdmDisconnect(cdm = cdm)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.