Helper for consistent documentation of table arguments.
Character string specifying the desired output table format. See
visOmopResults::tableType() for supported table types. If type = NULL,
global options (set via visOmopResults::setGlobalTableOptions()) will be
used if available; otherwise, a default 'gt' table is created.
Defines the visual formatting of the table. This argument can be provided in one of the following ways:
Pre-defined style: Use the name of a built-in style (e.g., "darwin").
See visOmopResults::tableStyle() for available options.
YAML file path: Provide the path to an existing .yml file defining a new style.
List of custome R code: Supply a block of custom R code or a named list describing styles for each table section. This code must be specific to the selected table type.
If style = NULL, the function will use global options
(seevisOmopResults::setGlobalTableOptions()) or a _brand.yml file
(if found); otherwise, the default style is applied.
A vector specifying the elements to include in the header. The order of elements matters, with the first being the topmost header.
Columns to drop from the output table.
Columns to use as group labels, to see options use visOmopResults::tableColumns(result).