Summarise a cdm_reference object creating a snapshot with the metadata of the cdm_reference object
Source:R/summariseOmopSnapshot.R
summariseOmopSnapshot.RdSummarise a cdm_reference object creating a snapshot with the metadata of the cdm_reference object
Examples
# \donttest{
library(OmopSketch)
library(omock)
cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
#> ℹ Loading bundled GiBleed tables from package data.
#> ℹ Adding drug_strength table.
#> ℹ Creating local <cdm_reference> object.
#> ℹ Inserting <cdm_reference> into duckdb.
#> duckdb keeps downloaded extensions and secrets in a temporary directory:
#> ℹ /tmp/RtmpHDb1h0/duckdb
#> This is removed when the R session ends.
#> • Extensions are re-downloaded each session.
#> • Secrets are lost.
#> ℹ Run duckdb(shared_home = TRUE) (or create ~/.duckdb) to keep them (suitable for most users).
#> ℹ Run duckdb(shared_home = FALSE) to accept the temporary directory (and silence this message).
#> ℹ See ?duckdb_storage for details and alternatives.
result <- summariseOmopSnapshot(cdm = cdm)
tableOmopSnapshot(result = result)
Snapshot of the cdm GiBleed
General
Cdm
Observation period
Cdm source
cdmDisconnect(cdm = cdm)
# }