Skip to contents

Only records that fall within the observation period are considered.

Usage

summariseRecordCount(
  cdm,
  omopTableName,
  interval = "overall",
  ageGroup = NULL,
  sex = FALSE,
  sample = NULL,
  dateRange = NULL
)

Arguments

cdm

A cdm_reference object. Use CDMConnector to create a reference to a database or omock to create a reference to synthetic data.

omopTableName

A character vector of the names of the tables to summarise in the cdm object. Run clinicalTables() to check the available options.

interval

Time interval to stratify by. It can either be "years", "quarters", "months" or "overall".

ageGroup

A list of age groups to stratify the results by. Each element represents a specific age range. You can give them specific names, e.g. ageGroup = list(children = c(0, 17), adult = c(18, Inf)).

sex

Logical; whether to stratify results by sex (TRUE) or not (FALSE).

sample

Either an integer or a character string.

  • If an integer (n > 0), the function will first sample n distinct person_ids from the person table and then subset the input tables to those subjects.

  • If a character string, it must be the name of a cohort in the cdm; in this case, the input tables are subset to subjects (subject_id) belonging to that cohort.

  • Use NULL to disable subsetting (default value).

dateRange

A vector of two dates defining the desired study period. Only the start_date column of the OMOP table is checked to ensure it falls within this range. If dateRange is NULL, no restriction is applied.

Value

A summarised_result object with the results.

Details

[Deprecated]

Examples

# \donttest{
library(OmopSketch)
library(dplyr, warn.conflicts = FALSE)
library(omock)

cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
#>  Loading bundled GiBleed tables from package data.
#>  Adding drug_strength table.
#>  Creating local <cdm_reference> object.
#>  Inserting <cdm_reference> into duckdb.
#> duckdb keeps downloaded extensions and secrets in a temporary directory:
#>  /tmp/RtmpHDb1h0/duckdb
#> This is removed when the R session ends.
#>  Extensions are re-downloaded each session.
#>  Secrets are lost.
#>  Run duckdb(shared_home = TRUE) (or create ~/.duckdb) to keep them (suitable for most users).
#>  Run duckdb(shared_home = FALSE) to accept the temporary directory (and silence this message).
#>  See ?duckdb_storage for details and alternatives.

result <- summariseRecordCount(
  cdm = cdm,
  omopTableName = c("condition_occurrence", "drug_exposure"),
  interval = "years",
  ageGroup = list("<=20" = c(0, 20), ">20" = c(21, Inf)),
  sex = TRUE
)

tableRecordCount(result = result)
#> Warning: `tableRecordCount()` was deprecated in OmopSketch 1.0.0.
#>  Please use `tableTrend()` instead.
Summary of Number of records, Number of records: end_date, Number of records: start_date by years in condition_occurrence, drug_exposure tables
Variable name Time interval Age group Sex Estimate name Interval
Database name
GiBleed
episode; condition_occurrence
Number of records overall overall overall N (%) years 65,332 (100.00%)
>20 overall N (%) years 40,402 (61.84%)
<=20 overall N (%) years 24,930 (38.16%)
overall Male N (%) years 31,588 (48.35%)
Female N (%) years 33,744 (51.65%)
<=20 Female N (%) years 12,746 (19.51%)
Male N (%) years 12,184 (18.65%)
>20 Male N (%) years 19,404 (29.70%)
Female N (%) years 20,998 (32.14%)
Number of records: end_date 1908-01-01 to 1908-12-31 overall overall N (%) years 1 (0.00%)
<=20 overall N (%) years 1 (0.00%)
overall Female N (%) years 1 (0.00%)
<=20 Female N (%) years 1 (0.00%)
1909-01-01 to 1909-12-31 overall overall N (%) years 4 (0.01%)
<=20 overall N (%) years 4 (0.01%)
overall Female N (%) years 4 (0.01%)
<=20 Female N (%) years 4 (0.01%)
1910-01-01 to 1910-12-31 overall overall N (%) years 14 (0.02%)
<=20 overall N (%) years 14 (0.02%)
overall Female N (%) years 14 (0.02%)
Male N (%) years 0 (0.00%)
<=20 Female N (%) years 14 (0.02%)
Male N (%) years 0 (0.00%)
1911-01-01 to 1911-12-31 overall overall N (%) years 16 (0.02%)
<=20 overall N (%) years 16 (0.02%)
overall Male N (%) years 3 (0.00%)
Female N (%) years 13 (0.02%)
<=20 Male N (%) years 3 (0.00%)
Female N (%) years 13 (0.02%)
1912-01-01 to 1912-12-31 overall overall N (%) years 28 (0.04%)
<=20 overall N (%) years 28 (0.04%)
overall Female N (%) years 21 (0.03%)
Male N (%) years 7 (0.01%)
<=20 Female N (%) years 21 (0.03%)
Male N (%) years 7 (0.01%)
1913-01-01 to 1913-12-31 overall overall N (%) years 34 (0.05%)
<=20 overall N (%) years 34 (0.05%)
overall Female N (%) years 25 (0.04%)
Male N (%) years 9 (0.01%)
<=20 Female N (%) years 25 (0.04%)
Male N (%) years 9 (0.01%)
1914-01-01 to 1914-12-31 overall overall N (%) years 35 (0.05%)
<=20 overall N (%) years 35 (0.05%)
overall Female N (%) years 28 (0.04%)
Male N (%) years 7 (0.01%)
<=20 Female N (%) years 28 (0.04%)
Male N (%) years 7 (0.01%)
1915-01-01 to 1915-12-31 overall overall N (%) years 35 (0.05%)
<=20 overall N (%) years 35 (0.05%)
overall Female N (%) years 21 (0.03%)
Male N (%) years 14 (0.02%)
<=20 Female N (%) years 21 (0.03%)
Male N (%) years 14 (0.02%)
1916-01-01 to 1916-12-31 overall overall N (%) years 42 (0.06%)
<=20 overall N (%) years 42 (0.06%)
overall Female N (%) years 29 (0.04%)
Male N (%) years 13 (0.02%)
<=20 Female N (%) years 29 (0.04%)
Male N (%) years 13 (0.02%)
1917-01-01 to 1917-12-31 overall overall N (%) years 42 (0.06%)
<=20 overall N (%) years 42 (0.06%)
overall Female N (%) years 24 (0.04%)
Male N (%) years 18 (0.03%)
<=20 Female N (%) years 24 (0.04%)
Male N (%) years 18 (0.03%)
1918-01-01 to 1918-12-31 overall overall N (%) years 36 (0.06%)
<=20 overall N (%) years 36 (0.06%)
overall Female N (%) years 21 (0.03%)
Male N (%) years 15 (0.02%)
<=20 Female N (%) years 21 (0.03%)
Male N (%) years 15 (0.02%)
1919-01-01 to 1919-12-31 overall overall N (%) years 43 (0.07%)
<=20 overall N (%) years 43 (0.07%)
overall Female N (%) years 25 (0.04%)
Male N (%) years 18 (0.03%)
<=20 Female N (%) years 25 (0.04%)
Male N (%) years 18 (0.03%)
1920-01-01 to 1920-12-31 overall overall N (%) years 48 (0.07%)
<=20 overall N (%) years 48 (0.07%)
overall Female N (%) years 30 (0.05%)
Male N (%) years 18 (0.03%)
<=20 Female N (%) years 30 (0.05%)
Male N (%) years 18 (0.03%)
1921-01-01 to 1921-12-31 overall overall N (%) years 51 (0.08%)
<=20 overall N (%) years 51 (0.08%)
overall Female N (%) years 34 (0.05%)
Male N (%) years 17 (0.03%)
<=20 Female N (%) years 34 (0.05%)
Male N (%) years 17 (0.03%)
1922-01-01 to 1922-12-31 overall overall N (%) years 59 (0.09%)
<=20 overall N (%) years 59 (0.09%)
overall Female N (%) years 34 (0.05%)
Male N (%) years 25 (0.04%)
<=20 Female N (%) years 34 (0.05%)
Male N (%) years 25 (0.04%)
1923-01-01 to 1923-12-31 overall overall N (%) years 67 (0.10%)
<=20 overall N (%) years 67 (0.10%)
overall Female N (%) years 39 (0.06%)
Male N (%) years 28 (0.04%)
<=20 Female N (%) years 39 (0.06%)
Male N (%) years 28 (0.04%)
1924-01-01 to 1924-12-31 overall overall N (%) years 62 (0.09%)
<=20 overall N (%) years 62 (0.09%)
overall Female N (%) years 36 (0.06%)
Male N (%) years 26 (0.04%)
<=20 Female N (%) years 36 (0.06%)
Male N (%) years 26 (0.04%)
1925-01-01 to 1925-12-31 overall overall N (%) years 70 (0.11%)
<=20 overall N (%) years 70 (0.11%)
overall Female N (%) years 42 (0.06%)
Male N (%) years 28 (0.04%)
<=20 Female N (%) years 42 (0.06%)
Male N (%) years 28 (0.04%)
1926-01-01 to 1926-12-31 overall overall N (%) years 75 (0.11%)
<=20 overall N (%) years 75 (0.11%)
overall Male N (%) years 33 (0.05%)
Female N (%) years 42 (0.06%)
<=20 Male N (%) years 33 (0.05%)
Female N (%) years 42 (0.06%)
1927-01-01 to 1927-12-31 overall overall N (%) years 73 (0.11%)
<=20 overall N (%) years 73 (0.11%)
overall Female N (%) years 34 (0.05%)
Male N (%) years 39 (0.06%)
<=20 Female N (%) years 34 (0.05%)
Male N (%) years 39 (0.06%)
1928-01-01 to 1928-12-31 overall overall N (%) years 79 (0.12%)
<=20 overall N (%) years 79 (0.12%)
overall Female N (%) years 51 (0.08%)
Male N (%) years 28 (0.04%)
<=20 Female N (%) years 51 (0.08%)
Male N (%) years 28 (0.04%)
1929-01-01 to 1929-12-31 overall overall N (%) years 66 (0.10%)
<=20 overall N (%) years 66 (0.10%)
overall Female N (%) years 40 (0.06%)
Male N (%) years 26 (0.04%)
<=20 Female N (%) years 40 (0.06%)
Male N (%) years 26 (0.04%)
1930-01-01 to 1930-12-31 overall overall N (%) years 58 (0.09%)
>20 overall N (%) years 6 (0.01%)
<=20 overall N (%) years 52 (0.08%)
overall Female N (%) years 31 (0.05%)
Male N (%) years 27 (0.04%)
<=20 Female N (%) years 25 (0.04%)
Male N (%) years 27 (0.04%)
>20 Female N (%) years 6 (0.01%)
1931-01-01 to 1931-12-31 overall overall N (%) years 84 (0.13%)
>20 overall N (%) years 5 (0.01%)
<=20 overall N (%) years 79 (0.12%)
overall Female N (%) years 54 (0.08%)
Male N (%) years 30 (0.05%)
<=20 Female N (%) years 49 (0.08%)
Male N (%) years 30 (0.05%)
>20 Female N (%) years 5 (0.01%)
1932-01-01 to 1932-12-31 overall overall N (%) years 72 (0.11%)
>20 overall N (%) years 3 (0.00%)
<=20 overall N (%) years 69 (0.11%)
overall Male N (%) years 31 (0.05%)
Female N (%) years 41 (0.06%)
>20 Female N (%) years 3 (0.00%)
<=20 Male N (%) years 31 (0.05%)
Female N (%) years 38 (0.06%)
1933-01-01 to 1933-12-31 overall overall N (%) years 77 (0.12%)
<=20 overall N (%) years 67 (0.10%)
>20 overall N (%) years 10 (0.02%)
overall Female N (%) years 40 (0.06%)
Male N (%) years 37 (0.06%)
<=20 Female N (%) years 33 (0.05%)
Male N (%) years 34 (0.05%)
>20 Female N (%) years 7 (0.01%)
Male N (%) years 3 (0.00%)
1934-01-01 to 1934-12-31 overall overall N (%) years 76 (0.12%)
<=20 overall N (%) years 60 (0.09%)
>20 overall N (%) years 16 (0.02%)
overall Male N (%) years 27 (0.04%)
Female N (%) years 49 (0.08%)
<=20 Male N (%) years 22 (0.03%)
Female N (%) years 38 (0.06%)
>20 Female N (%) years 11 (0.02%)
Male N (%) years 5 (0.01%)
1935-01-01 to 1935-12-31 overall overall N (%) years 75 (0.11%)
<=20 overall N (%) years 52 (0.08%)
>20 overall N (%) years 23 (0.04%)
overall Male N (%) years 37 (0.06%)
Female N (%) years 38 (0.06%)
<=20 Male N (%) years 30 (0.05%)
Female N (%) years 22 (0.03%)
>20 Female N (%) years 16 (0.02%)
Male N (%) years 7 (0.01%)
1936-01-01 to 1936-12-31 overall overall N (%) years 107 (0.16%)
>20 overall N (%) years 24 (0.04%)
<=20 overall N (%) years 83 (0.13%)
overall Female N (%) years 68 (0.10%)
Male N (%) years 39 (0.06%)
>20 Male N (%) years 7 (0.01%)
Female N (%) years 17 (0.03%)
<=20 Female N (%) years 51 (0.08%)
Male N (%) years 32 (0.05%)
1937-01-01 to 1937-12-31 overall overall N (%) years 116 (0.18%)
<=20 overall N (%) years 95 (0.15%)
>20 overall N (%) years 21 (0.03%)
overall Female N (%) years 68 (0.10%)
Male N (%) years 48 (0.07%)
<=20 Female N (%) years 52 (0.08%)
Male N (%) years 43 (0.07%)
>20 Female N (%) years 16 (0.02%)
Male N (%) years 5 (0.01%)
1938-01-01 to 1938-12-31 overall overall N (%) years 119 (0.18%)
<=20 overall N (%) years 87 (0.13%)
>20 overall N (%) years 32 (0.05%)
overall Female N (%) years 70 (0.11%)
Male N (%) years 49 (0.08%)
<=20 Female N (%) years 43 (0.07%)
Male N (%) years 44 (0.07%)
>20 Female N (%) years 27 (0.04%)
Male N (%) years 5 (0.01%)
1939-01-01 to 1939-12-31 overall overall N (%) years 127 (0.19%)
>20 overall N (%) years 30 (0.05%)
<=20 overall N (%) years 97 (0.15%)
overall Female N (%) years 68 (0.10%)
Male N (%) years 59 (0.09%)
<=20 Female N (%) years 50 (0.08%)
Male N (%) years 47 (0.07%)
>20 Female N (%) years 18 (0.03%)
Male N (%) years 12 (0.02%)
1940-01-01 to 1940-12-31 overall overall N (%) years 147 (0.23%)
>20 overall N (%) years 20 (0.03%)
<=20 overall N (%) years 127 (0.19%)
overall Female N (%) years 79 (0.12%)
Male N (%) years 68 (0.10%)
<=20 Female N (%) years 69 (0.11%)
Male N (%) years 58 (0.09%)
>20 Female N (%) years 10 (0.02%)
Male N (%) years 10 (0.02%)
1941-01-01 to 1941-12-31 overall overall N (%) years 152 (0.23%)
<=20 overall N (%) years 120 (0.18%)
>20 overall N (%) years 32 (0.05%)
overall Female N (%) years 72 (0.11%)
Male N (%) years 80 (0.12%)
>20 Male N (%) years 17 (0.03%)
Female N (%) years 15 (0.02%)
<=20 Female N (%) years 57 (0.09%)
Male N (%) years 63 (0.10%)
1942-01-01 to 1942-12-31 overall overall N (%) years 149 (0.23%)
<=20 overall N (%) years 111 (0.17%)
>20 overall N (%) years 38 (0.06%)
overall Male N (%) years 73 (0.11%)
Female N (%) years 76 (0.12%)
<=20 Male N (%) years 61 (0.09%)
>20 Female N (%) years 26 (0.04%)
<=20 Female N (%) years 50 (0.08%)
>20 Male N (%) years 12 (0.02%)
1943-01-01 to 1943-12-31 overall overall N (%) years 174 (0.27%)
>20 overall N (%) years 46 (0.07%)
<=20 overall N (%) years 128 (0.20%)
overall Female N (%) years 97 (0.15%)
Male N (%) years 77 (0.12%)
<=20 Female N (%) years 67 (0.10%)
Male N (%) years 61 (0.09%)
>20 Female N (%) years 30 (0.05%)
Male N (%) years 16 (0.02%)
1944-01-01 to 1944-12-31 overall overall N (%) years 188 (0.29%)
<=20 overall N (%) years 142 (0.22%)
>20 overall N (%) years 46 (0.07%)
overall Female N (%) years 86 (0.13%)
Male N (%) years 102 (0.16%)
>20 Female N (%) years 19 (0.03%)
Male N (%) years 27 (0.04%)
<=20 Female N (%) years 67 (0.10%)
Male N (%) years 75 (0.11%)
1945-01-01 to 1945-12-31 overall overall N (%) years 191 (0.29%)
>20 overall N (%) years 38 (0.06%)
<=20 overall N (%) years 153 (0.23%)
overall Female N (%) years 100 (0.15%)
Male N (%) years 91 (0.14%)
<=20 Female N (%) years 79 (0.12%)
Male N (%) years 74 (0.11%)
>20 Female N (%) years 21 (0.03%)
Male N (%) years 17 (0.03%)
1946-01-01 to 1946-12-31 overall overall N (%) years 216 (0.33%)
>20 overall N (%) years 53 (0.08%)
<=20 overall N (%) years 163 (0.25%)
overall Female N (%) years 119 (0.18%)
Male N (%) years 97 (0.15%)
<=20 Female N (%) years 86 (0.13%)
Male N (%) years 77 (0.12%)
>20 Female N (%) years 33 (0.05%)
Male N (%) years 20 (0.03%)
1947-01-01 to 1947-12-31 overall overall N (%) years 272 (0.42%)
<=20 overall N (%) years 204 (0.31%)
>20 overall N (%) years 68 (0.10%)
overall Female N (%) years 139 (0.21%)
Male N (%) years 133 (0.20%)
>20 Female N (%) years 41 (0.06%)
Male N (%) years 27 (0.04%)
<=20 Male N (%) years 106 (0.16%)
Female N (%) years 98 (0.15%)
1948-01-01 to 1948-12-31 overall overall N (%) years 250 (0.38%)
>20 overall N (%) years 62 (0.09%)
<=20 overall N (%) years 188 (0.29%)
overall Male N (%) years 118 (0.18%)
Female N (%) years 132 (0.20%)
<=20 Male N (%) years 89 (0.14%)
Female N (%) years 99 (0.15%)
>20 Male N (%) years 29 (0.04%)
Female N (%) years 33 (0.05%)
1949-01-01 to 1949-12-31 overall overall N (%) years 274 (0.42%)
>20 overall N (%) years 47 (0.07%)
<=20 overall N (%) years 227 (0.35%)
overall Female N (%) years 137 (0.21%)
Male N (%) years 137 (0.21%)
<=20 Female N (%) years 112 (0.17%)
Male N (%) years 115 (0.18%)
>20 Male N (%) years 22 (0.03%)
Female N (%) years 25 (0.04%)
1950-01-01 to 1950-12-31 overall overall N (%) years 306 (0.47%)
<=20 overall N (%) years 257 (0.39%)
>20 overall N (%) years 49 (0.08%)
overall Male N (%) years 149 (0.23%)
Female N (%) years 157 (0.24%)
<=20 Male N (%) years 127 (0.19%)
Female N (%) years 130 (0.20%)
>20 Male N (%) years 22 (0.03%)
Female N (%) years 27 (0.04%)
1951-01-01 to 1951-12-31 overall overall N (%) years 333 (0.51%)
<=20 overall N (%) years 287 (0.44%)
>20 overall N (%) years 46 (0.07%)
overall Male N (%) years 166 (0.25%)
Female N (%) years 167 (0.26%)
<=20 Male N (%) years 149 (0.23%)
Female N (%) years 138 (0.21%)
>20 Male N (%) years 17 (0.03%)
Female N (%) years 29 (0.04%)
1952-01-01 to 1952-12-31 overall overall N (%) years 380 (0.58%)
>20 overall N (%) years 68 (0.10%)
<=20 overall N (%) years 312 (0.48%)
overall Male N (%) years 191 (0.29%)
Female N (%) years 189 (0.29%)
>20 Female N (%) years 44 (0.07%)
Male N (%) years 24 (0.04%)
<=20 Male N (%) years 167 (0.26%)
Female N (%) years 145 (0.22%)
1953-01-01 to 1953-12-31 overall overall N (%) years 374 (0.57%)
<=20 overall N (%) years 316 (0.48%)
>20 overall N (%) years 58 (0.09%)
overall Male N (%) years 182 (0.28%)
Female N (%) years 192 (0.29%)
<=20 Male N (%) years 160 (0.24%)
Female N (%) years 156 (0.24%)
>20 Male N (%) years 22 (0.03%)
Female N (%) years 36 (0.06%)
1954-01-01 to 1954-12-31 overall overall N (%) years 392 (0.60%)
<=20 overall N (%) years 331 (0.51%)
>20 overall N (%) years 61 (0.09%)
overall Female N (%) years 202 (0.31%)
Male N (%) years 190 (0.29%)
<=20 Female N (%) years 166 (0.25%)
Male N (%) years 165 (0.25%)
>20 Female N (%) years 36 (0.06%)
Male N (%) years 25 (0.04%)
1955-01-01 to 1955-12-31 overall overall N (%) years 411 (0.63%)
<=20 overall N (%) years 351 (0.54%)
>20 overall N (%) years 60 (0.09%)
overall Male N (%) years 208 (0.32%)
Female N (%) years 203 (0.31%)
>20 Female N (%) years 30 (0.05%)
Male N (%) years 30 (0.05%)
<=20 Male N (%) years 178 (0.27%)
Female N (%) years 173 (0.26%)
1956-01-01 to 1956-12-31 overall overall N (%) years 434 (0.66%)
>20 overall N (%) years 83 (0.13%)
<=20 overall N (%) years 351 (0.54%)
overall Male N (%) years 188 (0.29%)
Female N (%) years 246 (0.38%)
<=20 Male N (%) years 154 (0.24%)
Female N (%) years 197 (0.30%)
>20 Female N (%) years 49 (0.08%)
Male N (%) years 34 (0.05%)
1957-01-01 to 1957-12-31 overall overall N (%) years 445 (0.68%)
<=20 overall N (%) years 371 (0.57%)
>20 overall N (%) years 74 (0.11%)
overall Female N (%) years 234 (0.36%)
Male N (%) years 211 (0.32%)
<=20 Female N (%) years 190 (0.29%)
Male N (%) years 181 (0.28%)
>20 Female N (%) years 44 (0.07%)
Male N (%) years 30 (0.05%)
1958-01-01 to 1958-12-31 overall overall N (%) years 506 (0.77%)
<=20 overall N (%) years 421 (0.64%)
>20 overall N (%) years 85 (0.13%)
overall Female N (%) years 250 (0.38%)
Male N (%) years 256 (0.39%)
<=20 Female N (%) years 202 (0.31%)
Male N (%) years 219 (0.34%)
>20 Female N (%) years 48 (0.07%)
Male N (%) years 37 (0.06%)
1959-01-01 to 1959-12-31 overall overall N (%) years 530 (0.81%)
<=20 overall N (%) years 437 (0.67%)
>20 overall N (%) years 93 (0.14%)
overall Female N (%) years 278 (0.43%)
Male N (%) years 252 (0.39%)
>20 Female N (%) years 55 (0.08%)
Male N (%) years 38 (0.06%)
<=20 Male N (%) years 214 (0.33%)
Female N (%) years 223 (0.34%)
1960-01-01 to 1960-12-31 overall overall N (%) years 513 (0.79%)
>20 overall N (%) years 103 (0.16%)
<=20 overall N (%) years 410 (0.63%)
overall Male N (%) years 267 (0.41%)
Female N (%) years 246 (0.38%)
<=20 Male N (%) years 217 (0.33%)
Female N (%) years 193 (0.30%)
>20 Female N (%) years 53 (0.08%)
Male N (%) years 50 (0.08%)
1961-01-01 to 1961-12-31 overall overall N (%) years 564 (0.86%)
>20 overall N (%) years 115 (0.18%)
<=20 overall N (%) years 449 (0.69%)
overall Male N (%) years 268 (0.41%)
Female N (%) years 296 (0.45%)
<=20 Male N (%) years 225 (0.34%)
>20 Male N (%) years 43 (0.07%)
<=20 Female N (%) years 224 (0.34%)
>20 Female N (%) years 72 (0.11%)
1962-01-01 to 1962-12-31 overall overall N (%) years 617 (0.94%)
>20 overall N (%) years 102 (0.16%)
<=20 overall N (%) years 515 (0.79%)
overall Female N (%) years 310 (0.47%)
Male N (%) years 307 (0.47%)
<=20 Female N (%) years 252 (0.39%)
Male N (%) years 263 (0.40%)
>20 Male N (%) years 44 (0.07%)
Female N (%) years 58 (0.09%)
1963-01-01 to 1963-12-31 overall overall N (%) years 578 (0.88%)
<=20 overall N (%) years 480 (0.73%)
>20 overall N (%) years 98 (0.15%)
overall Female N (%) years 284 (0.43%)
Male N (%) years 294 (0.45%)
>20 Female N (%) years 50 (0.08%)
Male N (%) years 48 (0.07%)
<=20 Female N (%) years 234 (0.36%)
Male N (%) years 246 (0.38%)
1964-01-01 to 1964-12-31 overall overall N (%) years 660 (1.01%)
<=20 overall N (%) years 527 (0.81%)
>20 overall N (%) years 133 (0.20%)
overall Female N (%) years 337 (0.52%)
Male N (%) years 323 (0.49%)
>20 Female N (%) years 75 (0.11%)
<=20 Female N (%) years 262 (0.40%)
>20 Male N (%) years 58 (0.09%)
<=20 Male N (%) years 265 (0.41%)
1965-01-01 to 1965-12-31 overall overall N (%) years 702 (1.07%)
>20 overall N (%) years 137 (0.21%)
<=20 overall N (%) years 565 (0.86%)
overall Male N (%) years 363 (0.56%)
Female N (%) years 339 (0.52%)
<=20 Male N (%) years 297 (0.45%)
Female N (%) years 268 (0.41%)
>20 Female N (%) years 71 (0.11%)
Male N (%) years 66 (0.10%)
1966-01-01 to 1966-12-31 overall overall N (%) years 701 (1.07%)
>20 overall N (%) years 151 (0.23%)
<=20 overall N (%) years 550 (0.84%)
overall Male N (%) years 333 (0.51%)
Female N (%) years 368 (0.56%)
<=20 Male N (%) years 272 (0.42%)
Female N (%) years 278 (0.43%)
>20 Male N (%) years 61 (0.09%)
Female N (%) years 90 (0.14%)
1967-01-01 to 1967-12-31 overall overall N (%) years 758 (1.16%)
<=20 overall N (%) years 577 (0.88%)
>20 overall N (%) years 181 (0.28%)
overall Male N (%) years 373 (0.57%)
Female N (%) years 385 (0.59%)
<=20 Male N (%) years 292 (0.45%)
Female N (%) years 285 (0.44%)
>20 Male N (%) years 81 (0.12%)
Female N (%) years 100 (0.15%)
1968-01-01 to 1968-12-31 overall overall N (%) years 811 (1.24%)
<=20 overall N (%) years 631 (0.97%)
>20 overall N (%) years 180 (0.28%)
overall Female N (%) years 416 (0.64%)
Male N (%) years 395 (0.60%)
<=20 Male N (%) years 322 (0.49%)
Female N (%) years 309 (0.47%)
>20 Female N (%) years 107 (0.16%)
Male N (%) years 73 (0.11%)
1969-01-01 to 1969-12-31 overall overall N (%) years 764 (1.17%)
<=20 overall N (%) years 583 (0.89%)
>20 overall N (%) years 181 (0.28%)
overall Male N (%) years 369 (0.56%)
Female N (%) years 395 (0.60%)
>20 Female N (%) years 97 (0.15%)
Male N (%) years 84 (0.13%)
<=20 Male N (%) years 285 (0.44%)
Female N (%) years 298 (0.46%)
1970-01-01 to 1970-12-31 overall overall N (%) years 755 (1.16%)
>20 overall N (%) years 187 (0.29%)
<=20 overall N (%) years 568 (0.87%)
overall Male N (%) years 361 (0.55%)
Female N (%) years 394 (0.60%)
>20 Female N (%) years 102 (0.16%)
Male N (%) years 85 (0.13%)
<=20 Male N (%) years 276 (0.42%)
Female N (%) years 292 (0.45%)
1971-01-01 to 1971-12-31 overall overall N (%) years 808 (1.24%)
<=20 overall N (%) years 577 (0.88%)
>20 overall N (%) years 231 (0.35%)
overall Male N (%) years 394 (0.60%)
Female N (%) years 414 (0.63%)
>20 Male N (%) years 105 (0.16%)
Female N (%) years 126 (0.19%)
<=20 Male N (%) years 289 (0.44%)
Female N (%) years 288 (0.44%)
1972-01-01 to 1972-12-31 overall overall N (%) years 803 (1.23%)
<=20 overall N (%) years 579 (0.89%)
>20 overall N (%) years 224 (0.34%)
overall Female N (%) years 423 (0.65%)
Male N (%) years 380 (0.58%)
>20 Female N (%) years 121 (0.19%)
<=20 Female N (%) years 302 (0.46%)
Male N (%) years 277 (0.42%)
>20 Male N (%) years 103 (0.16%)
1973-01-01 to 1973-12-31 overall overall N (%) years 897 (1.37%)
>20 overall N (%) years 232 (0.36%)
<=20 overall N (%) years 665 (1.02%)
overall Female N (%) years 463 (0.71%)
Male N (%) years 434 (0.66%)
>20 Female N (%) years 111 (0.17%)
<=20 Female N (%) years 352 (0.54%)
Male N (%) years 313 (0.48%)
>20 Male N (%) years 121 (0.19%)
1974-01-01 to 1974-12-31 overall overall N (%) years 864 (1.32%)
<=20 overall N (%) years 624 (0.96%)
>20 overall N (%) years 240 (0.37%)
overall Male N (%) years 432 (0.66%)
Female N (%) years 432 (0.66%)
<=20 Male N (%) years 321 (0.49%)
Female N (%) years 303 (0.46%)
>20 Female N (%) years 129 (0.20%)
Male N (%) years 111 (0.17%)
1975-01-01 to 1975-12-31 overall overall N (%) years 875 (1.34%)
>20 overall N (%) years 281 (0.43%)
<=20 overall N (%) years 594 (0.91%)
overall Female N (%) years 438 (0.67%)
Male N (%) years 437 (0.67%)
>20 Female N (%) years 132 (0.20%)
Male N (%) years 149 (0.23%)
<=20 Female N (%) years 306 (0.47%)
Male N (%) years 288 (0.44%)
1976-01-01 to 1976-12-31 overall overall N (%) years 875 (1.34%)
>20 overall N (%) years 296 (0.45%)
<=20 overall N (%) years 579 (0.89%)
overall Male N (%) years 434 (0.66%)
Female N (%) years 441 (0.68%)
<=20 Male N (%) years 300 (0.46%)
Female N (%) years 279 (0.43%)
>20 Female N (%) years 162 (0.25%)
Male N (%) years 134 (0.21%)
1977-01-01 to 1977-12-31 overall overall N (%) years 910 (1.39%)
<=20 overall N (%) years 577 (0.88%)
>20 overall N (%) years 333 (0.51%)
overall Female N (%) years 455 (0.70%)
Male N (%) years 455 (0.70%)
>20 Female N (%) years 175 (0.27%)
Male N (%) years 158 (0.24%)
<=20 Female N (%) years 280 (0.43%)
Male N (%) years 297 (0.45%)
1978-01-01 to 1978-12-31 overall overall N (%) years 1,009 (1.54%)
>20 overall N (%) years 364 (0.56%)
<=20 overall N (%) years 645 (0.99%)
overall Female N (%) years 513 (0.79%)
Male N (%) years 496 (0.76%)
>20 Female N (%) years 192 (0.29%)
Male N (%) years 172 (0.26%)
<=20 Male N (%) years 324 (0.50%)
Female N (%) years 321 (0.49%)
1979-01-01 to 1979-12-31 overall overall N (%) years 966 (1.48%)
<=20 overall N (%) years 590 (0.90%)
>20 overall N (%) years 376 (0.58%)
overall Male N (%) years 452 (0.69%)
Female N (%) years 514 (0.79%)
>20 Male N (%) years 171 (0.26%)
Female N (%) years 205 (0.31%)
<=20 Male N (%) years 281 (0.43%)
Female N (%) years 309 (0.47%)
1980-01-01 to 1980-12-31 overall overall N (%) years 979 (1.50%)
>20 overall N (%) years 404 (0.62%)
<=20 overall N (%) years 575 (0.88%)
overall Female N (%) years 483 (0.74%)
Male N (%) years 496 (0.76%)
<=20 Female N (%) years 285 (0.44%)
Male N (%) years 290 (0.44%)
>20 Male N (%) years 206 (0.32%)
Female N (%) years 198 (0.30%)
1981-01-01 to 1981-12-31 overall overall N (%) years 939 (1.44%)
>20 overall N (%) years 402 (0.62%)
<=20 overall N (%) years 537 (0.82%)
overall Male N (%) years 427 (0.65%)
Female N (%) years 512 (0.78%)
>20 Male N (%) years 188 (0.29%)
Female N (%) years 214 (0.33%)
<=20 Male N (%) years 239 (0.37%)
Female N (%) years 298 (0.46%)
1982-01-01 to 1982-12-31 overall overall N (%) years 923 (1.41%)
<=20 overall N (%) years 501 (0.77%)
>20 overall N (%) years 422 (0.65%)
overall Male N (%) years 450 (0.69%)
Female N (%) years 473 (0.72%)
<=20 Male N (%) years 249 (0.38%)
Female N (%) years 252 (0.39%)
>20 Male N (%) years 201 (0.31%)
Female N (%) years 221 (0.34%)
1983-01-01 to 1983-12-31 overall overall N (%) years 907 (1.39%)
<=20 overall N (%) years 465 (0.71%)
>20 overall N (%) years 442 (0.68%)
overall Female N (%) years 471 (0.72%)
Male N (%) years 436 (0.67%)
>20 Female N (%) years 232 (0.36%)
Male N (%) years 210 (0.32%)
<=20 Male N (%) years 226 (0.35%)
Female N (%) years 239 (0.37%)
1984-01-01 to 1984-12-31 overall overall N (%) years 958 (1.47%)
>20 overall N (%) years 460 (0.70%)
<=20 overall N (%) years 498 (0.76%)
overall Female N (%) years 512 (0.78%)
Male N (%) years 446 (0.68%)
<=20 Female N (%) years 271 (0.41%)
Male N (%) years 227 (0.35%)
>20 Male N (%) years 219 (0.34%)
Female N (%) years 241 (0.37%)
1985-01-01 to 1985-12-31 overall overall N (%) years 896 (1.37%)
<=20 overall N (%) years 419 (0.64%)
>20 overall N (%) years 477 (0.73%)
overall Male N (%) years 423 (0.65%)
Female N (%) years 473 (0.72%)
<=20 Male N (%) years 203 (0.31%)
>20 Male N (%) years 220 (0.34%)
Female N (%) years 257 (0.39%)
<=20 Female N (%) years 216 (0.33%)
1986-01-01 to 1986-12-31 overall overall N (%) years 934 (1.43%)
<=20 overall N (%) years 404 (0.62%)
>20 overall N (%) years 530 (0.81%)
overall Female N (%) years 505 (0.77%)
Male N (%) years 429 (0.66%)
<=20 Female N (%) years 212 (0.32%)
Male N (%) years 192 (0.29%)
>20 Male N (%) years 237 (0.36%)
Female N (%) years 293 (0.45%)
1987-01-01 to 1987-12-31 overall overall N (%) years 935 (1.43%)
<=20 overall N (%) years 379 (0.58%)
>20 overall N (%) years 556 (0.85%)
overall Female N (%) years 481 (0.74%)
Male N (%) years 454 (0.69%)
<=20 Female N (%) years 188 (0.29%)
Male N (%) years 191 (0.29%)
>20 Female N (%) years 293 (0.45%)
Male N (%) years 263 (0.40%)
1988-01-01 to 1988-12-31 overall overall N (%) years 835 (1.28%)
>20 overall N (%) years 504 (0.77%)
<=20 overall N (%) years 331 (0.51%)
overall Female N (%) years 426 (0.65%)
Male N (%) years 409 (0.63%)
>20 Female N (%) years 261 (0.40%)
Male N (%) years 243 (0.37%)
<=20 Female N (%) years 165 (0.25%)
Male N (%) years 166 (0.25%)
1989-01-01 to 1989-12-31 overall overall N (%) years 891 (1.36%)
>20 overall N (%) years 588 (0.90%)
<=20 overall N (%) years 303 (0.46%)
overall Female N (%) years 495 (0.76%)
Male N (%) years 396 (0.61%)
>20 Female N (%) years 320 (0.49%)
<=20 Female N (%) years 175 (0.27%)
>20 Male N (%) years 268 (0.41%)
<=20 Male N (%) years 128 (0.20%)
1990-01-01 to 1990-12-31 overall overall N (%) years 879 (1.35%)
<=20 overall N (%) years 288 (0.44%)
>20 overall N (%) years 591 (0.90%)
overall Female N (%) years 468 (0.72%)
Male N (%) years 411 (0.63%)
>20 Female N (%) years 321 (0.49%)
Male N (%) years 270 (0.41%)
<=20 Female N (%) years 147 (0.23%)
Male N (%) years 141 (0.22%)
1991-01-01 to 1991-12-31 overall overall N (%) years 850 (1.30%)
<=20 overall N (%) years 231 (0.35%)
>20 overall N (%) years 619 (0.95%)
overall Male N (%) years 423 (0.65%)
Female N (%) years 427 (0.65%)
<=20 Male N (%) years 106 (0.16%)
>20 Female N (%) years 302 (0.46%)
<=20 Female N (%) years 125 (0.19%)
>20 Male N (%) years 317 (0.49%)
1992-01-01 to 1992-12-31 overall overall N (%) years 828 (1.27%)
<=20 overall N (%) years 207 (0.32%)
>20 overall N (%) years 621 (0.95%)
overall Male N (%) years 420 (0.64%)
Female N (%) years 408 (0.62%)
>20 Male N (%) years 318 (0.49%)
Female N (%) years 303 (0.46%)
<=20 Female N (%) years 105 (0.16%)
Male N (%) years 102 (0.16%)
1993-01-01 to 1993-12-31 overall overall N (%) years 908 (1.39%)
>20 overall N (%) years 698 (1.07%)
<=20 overall N (%) years 210 (0.32%)
overall Female N (%) years 462 (0.71%)
Male N (%) years 446 (0.68%)
>20 Female N (%) years 347 (0.53%)
<=20 Female N (%) years 115 (0.18%)
>20 Male N (%) years 351 (0.54%)
<=20 Male N (%) years 95 (0.15%)
1994-01-01 to 1994-12-31 overall overall N (%) years 843 (1.29%)
>20 overall N (%) years 677 (1.04%)
<=20 overall N (%) years 166 (0.25%)
overall Female N (%) years 421 (0.64%)
Male N (%) years 422 (0.65%)
>20 Female N (%) years 340 (0.52%)
Male N (%) years 337 (0.52%)
<=20 Female N (%) years 81 (0.12%)
Male N (%) years 85 (0.13%)
1995-01-01 to 1995-12-31 overall overall N (%) years 855 (1.31%)
>20 overall N (%) years 709 (1.09%)
<=20 overall N (%) years 146 (0.22%)
overall Male N (%) years 420 (0.64%)
Female N (%) years 435 (0.67%)
>20 Male N (%) years 350 (0.54%)
Female N (%) years 359 (0.55%)
<=20 Male N (%) years 70 (0.11%)
Female N (%) years 76 (0.12%)
1996-01-01 to 1996-12-31 overall overall N (%) years 863 (1.32%)
<=20 overall N (%) years 121 (0.19%)
>20 overall N (%) years 742 (1.14%)
overall Male N (%) years 408 (0.62%)
Female N (%) years 455 (0.70%)
<=20 Male N (%) years 49 (0.08%)
Female N (%) years 72 (0.11%)
>20 Female N (%) years 383 (0.59%)
Male N (%) years 359 (0.55%)
1997-01-01 to 1997-12-31 overall overall N (%) years 824 (1.26%)
<=20 overall N (%) years 106 (0.16%)
>20 overall N (%) years 718 (1.10%)
overall Female N (%) years 438 (0.67%)
Male N (%) years 386 (0.59%)
>20 Female N (%) years 377 (0.58%)
<=20 Female N (%) years 61 (0.09%)
>20 Male N (%) years 341 (0.52%)
<=20 Male N (%) years 45 (0.07%)
1998-01-01 to 1998-12-31 overall overall N (%) years 855 (1.31%)
<=20 overall N (%) years 101 (0.15%)
>20 overall N (%) years 754 (1.15%)
overall Male N (%) years 417 (0.64%)
Female N (%) years 438 (0.67%)
>20 Female N (%) years 384 (0.59%)
Male N (%) years 370 (0.57%)
<=20 Male N (%) years 47 (0.07%)
Female N (%) years 54 (0.08%)
1999-01-01 to 1999-12-31 overall overall N (%) years 850 (1.30%)
>20 overall N (%) years 787 (1.20%)
<=20 overall N (%) years 63 (0.10%)
overall Female N (%) years 449 (0.69%)
Male N (%) years 401 (0.61%)
>20 Female N (%) years 416 (0.64%)
Male N (%) years 371 (0.57%)
<=20 Male N (%) years 30 (0.05%)
Female N (%) years 33 (0.05%)
2000-01-01 to 2000-12-31 overall overall N (%) years 830 (1.27%)
>20 overall N (%) years 782 (1.20%)
<=20 overall N (%) years 48 (0.07%)
overall Female N (%) years 432 (0.66%)
Male N (%) years 398 (0.61%)
>20 Female N (%) years 407 (0.62%)
Male N (%) years 375 (0.57%)
<=20 Male N (%) years 23 (0.04%)
Female N (%) years 25 (0.04%)
2001-01-01 to 2001-12-31 overall overall N (%) years 767 (1.17%)
<=20 overall N (%) years 34 (0.05%)
>20 overall N (%) years 733 (1.12%)
overall Female N (%) years 400 (0.61%)
Male N (%) years 367 (0.56%)
<=20 Female N (%) years 21 (0.03%)
Male N (%) years 13 (0.02%)
>20 Female N (%) years 379 (0.58%)
Male N (%) years 354 (0.54%)
2002-01-01 to 2002-12-31 overall overall N (%) years 792 (1.21%)
<=20 overall N (%) years 25 (0.04%)
>20 overall N (%) years 767 (1.17%)
overall Male N (%) years 395 (0.60%)
Female N (%) years 397 (0.61%)
>20 Male N (%) years 378 (0.58%)
Female N (%) years 389 (0.60%)
<=20 Male N (%) years 17 (0.03%)
Female N (%) years 8 (0.01%)
2003-01-01 to 2003-12-31 overall overall N (%) years 766 (1.17%)
>20 overall N (%) years 756 (1.16%)
<=20 overall N (%) years 10 (0.02%)
overall Male N (%) years 389 (0.60%)
Female N (%) years 377 (0.58%)
<=20 Female N (%) years 8 (0.01%)
Male N (%) years 2 (0.00%)
>20 Male N (%) years 387 (0.59%)
Female N (%) years 369 (0.56%)
2004-01-01 to 2004-12-31 overall overall N (%) years 838 (1.28%)
>20 overall N (%) years 828 (1.27%)
<=20 overall N (%) years 10 (0.02%)
overall Female N (%) years 442 (0.68%)
Male N (%) years 396 (0.61%)
>20 Female N (%) years 437 (0.67%)
Male N (%) years 391 (0.60%)
<=20 Female N (%) years 5 (0.01%)
Male N (%) years 5 (0.01%)
2005-01-01 to 2005-12-31 overall overall N (%) years 808 (1.24%)
<=20 overall N (%) years 3 (0.00%)
>20 overall N (%) years 805 (1.23%)
overall Male N (%) years 385 (0.59%)
Female N (%) years 423 (0.65%)
>20 Male N (%) years 384 (0.59%)
Female N (%) years 421 (0.64%)
<=20 Female N (%) years 2 (0.00%)
Male N (%) years 1 (0.00%)
2006-01-01 to 2006-12-31 overall overall N (%) years 791 (1.21%)
<=20 overall N (%) years 1 (0.00%)
>20 overall N (%) years 790 (1.21%)
overall Female N (%) years 412 (0.63%)
Male N (%) years 379 (0.58%)
>20 Female N (%) years 411 (0.63%)
Male N (%) years 379 (0.58%)
<=20 Female N (%) years 1 (0.00%)
2007-01-01 to 2007-12-31 overall overall N (%) years 800 (1.22%)
>20 overall N (%) years 800 (1.22%)
overall Male N (%) years 392 (0.60%)
Female N (%) years 408 (0.62%)
>20 Male N (%) years 392 (0.60%)
Female N (%) years 408 (0.62%)
2008-01-01 to 2008-12-31 overall overall N (%) years 856 (1.31%)
>20 overall N (%) years 856 (1.31%)
overall Female N (%) years 432 (0.66%)
Male N (%) years 424 (0.65%)
>20 Female N (%) years 432 (0.66%)
Male N (%) years 424 (0.65%)
2009-01-01 to 2009-12-31 overall overall N (%) years 760 (1.16%)
>20 overall N (%) years 760 (1.16%)
overall Male N (%) years 368 (0.56%)
Female N (%) years 392 (0.60%)
>20 Male N (%) years 368 (0.56%)
Female N (%) years 392 (0.60%)
2010-01-01 to 2010-12-31 overall overall N (%) years 797 (1.22%)
>20 overall N (%) years 797 (1.22%)
overall Male N (%) years 382 (0.58%)
Female N (%) years 415 (0.64%)
>20 Male N (%) years 382 (0.58%)
Female N (%) years 415 (0.64%)
2011-01-01 to 2011-12-31 overall overall N (%) years 804 (1.23%)
>20 overall N (%) years 804 (1.23%)
overall Male N (%) years 401 (0.61%)
Female N (%) years 403 (0.62%)
>20 Male N (%) years 401 (0.61%)
Female N (%) years 403 (0.62%)
2012-01-01 to 2012-12-31 overall overall N (%) years 797 (1.22%)
>20 overall N (%) years 797 (1.22%)
overall Female N (%) years 406 (0.62%)
Male N (%) years 391 (0.60%)
>20 Female N (%) years 406 (0.62%)
Male N (%) years 391 (0.60%)
2013-01-01 to 2013-12-31 overall overall N (%) years 771 (1.18%)
>20 overall N (%) years 771 (1.18%)
overall Male N (%) years 363 (0.56%)
Female N (%) years 408 (0.62%)
>20 Male N (%) years 363 (0.56%)
Female N (%) years 408 (0.62%)
2014-01-01 to 2014-12-31 overall overall N (%) years 787 (1.20%)
>20 overall N (%) years 787 (1.20%)
overall Female N (%) years 425 (0.65%)
Male N (%) years 362 (0.55%)
>20 Female N (%) years 425 (0.65%)
Male N (%) years 362 (0.55%)
2015-01-01 to 2015-12-31 overall overall N (%) years 742 (1.14%)
>20 overall N (%) years 742 (1.14%)
overall Male N (%) years 358 (0.55%)
Female N (%) years 384 (0.59%)
>20 Male N (%) years 358 (0.55%)
Female N (%) years 384 (0.59%)
2016-01-01 to 2016-12-31 overall overall N (%) years 813 (1.24%)
>20 overall N (%) years 813 (1.24%)
overall Male N (%) years 385 (0.59%)
Female N (%) years 428 (0.66%)
>20 Male N (%) years 385 (0.59%)
Female N (%) years 428 (0.66%)
2017-01-01 to 2017-12-31 overall overall N (%) years 812 (1.24%)
>20 overall N (%) years 812 (1.24%)
overall Female N (%) years 408 (0.62%)
Male N (%) years 404 (0.62%)
>20 Female N (%) years 408 (0.62%)
Male N (%) years 404 (0.62%)
2018-01-01 to 2018-12-31 overall overall N (%) years 812 (1.24%)
>20 overall N (%) years 812 (1.24%)
overall Female N (%) years 396 (0.61%)
Male N (%) years 416 (0.64%)
>20 Female N (%) years 396 (0.61%)
Male N (%) years 416 (0.64%)
2019-01-01 to 2019-12-31 overall overall N (%) years 340 (0.52%)
>20 overall N (%) years 340 (0.52%)
overall Male N (%) years 166 (0.25%)
Female N (%) years 174 (0.27%)
>20 Male N (%) years 166 (0.25%)
Female N (%) years 174 (0.27%)
Number of records: start_date 1908-01-01 to 1908-12-31 overall overall N (%) years 1 (0.00%)
<=20 overall N (%) years 1 (0.00%)
overall Female N (%) years 1 (0.00%)
<=20 Female N (%) years 1 (0.00%)
1909-01-01 to 1909-12-31 overall overall N (%) years 4 (0.01%)
<=20 overall N (%) years 4 (0.01%)
overall Female N (%) years 4 (0.01%)
<=20 Female N (%) years 4 (0.01%)
1910-01-01 to 1910-12-31 overall overall N (%) years 16 (0.02%)
<=20 overall N (%) years 16 (0.02%)
overall Female N (%) years 15 (0.02%)
Male N (%) years 1 (0.00%)
<=20 Female N (%) years 15 (0.02%)
Male N (%) years 1 (0.00%)
1911-01-01 to 1911-12-31 overall overall N (%) years 20 (0.03%)
<=20 overall N (%) years 20 (0.03%)
overall Male N (%) years 6 (0.01%)
Female N (%) years 14 (0.02%)
<=20 Male N (%) years 6 (0.01%)
Female N (%) years 14 (0.02%)
1912-01-01 to 1912-12-31 overall overall N (%) years 34 (0.05%)
<=20 overall N (%) years 34 (0.05%)
overall Female N (%) years 27 (0.04%)
Male N (%) years 7 (0.01%)
<=20 Female N (%) years 27 (0.04%)
Male N (%) years 7 (0.01%)
1913-01-01 to 1913-12-31 overall overall N (%) years 43 (0.07%)
<=20 overall N (%) years 43 (0.07%)
overall Female N (%) years 33 (0.05%)
Male N (%) years 10 (0.02%)
<=20 Female N (%) years 33 (0.05%)
Male N (%) years 10 (0.02%)
1914-01-01 to 1914-12-31 overall overall N (%) years 40 (0.06%)
<=20 overall N (%) years 40 (0.06%)
overall Female N (%) years 33 (0.05%)
Male N (%) years 7 (0.01%)
<=20 Female N (%) years 33 (0.05%)
Male N (%) years 7 (0.01%)
1915-01-01 to 1915-12-31 overall overall N (%) years 44 (0.07%)
<=20 overall N (%) years 44 (0.07%)
overall Female N (%) years 28 (0.04%)
Male N (%) years 16 (0.02%)
<=20 Female N (%) years 28 (0.04%)
Male N (%) years 16 (0.02%)
1916-01-01 to 1916-12-31 overall overall N (%) years 49 (0.08%)
<=20 overall N (%) years 49 (0.08%)
overall Female N (%) years 36 (0.06%)
Male N (%) years 13 (0.02%)
<=20 Female N (%) years 36 (0.06%)
Male N (%) years 13 (0.02%)
1917-01-01 to 1917-12-31 overall overall N (%) years 49 (0.08%)
<=20 overall N (%) years 49 (0.08%)
overall Female N (%) years 27 (0.04%)
Male N (%) years 22 (0.03%)
<=20 Female N (%) years 27 (0.04%)
Male N (%) years 22 (0.03%)
1918-01-01 to 1918-12-31 overall overall N (%) years 42 (0.06%)
<=20 overall N (%) years 42 (0.06%)
overall Female N (%) years 25 (0.04%)
Male N (%) years 17 (0.03%)
<=20 Female N (%) years 25 (0.04%)
Male N (%) years 17 (0.03%)
1919-01-01 to 1919-12-31 overall overall N (%) years 49 (0.08%)
<=20 overall N (%) years 49 (0.08%)
overall Female N (%) years 29 (0.04%)
Male N (%) years 20 (0.03%)
<=20 Female N (%) years 29 (0.04%)
Male N (%) years 20 (0.03%)
1920-01-01 to 1920-12-31 overall overall N (%) years 56 (0.09%)
<=20 overall N (%) years 56 (0.09%)
overall Female N (%) years 33 (0.05%)
Male N (%) years 23 (0.04%)
<=20 Female N (%) years 33 (0.05%)
Male N (%) years 23 (0.04%)
1921-01-01 to 1921-12-31 overall overall N (%) years 64 (0.10%)
<=20 overall N (%) years 64 (0.10%)
overall Female N (%) years 42 (0.06%)
Male N (%) years 22 (0.03%)
<=20 Female N (%) years 42 (0.06%)
Male N (%) years 22 (0.03%)
1922-01-01 to 1922-12-31 overall overall N (%) years 73 (0.11%)
<=20 overall N (%) years 73 (0.11%)
overall Female N (%) years 41 (0.06%)
Male N (%) years 32 (0.05%)
<=20 Female N (%) years 41 (0.06%)
Male N (%) years 32 (0.05%)
1923-01-01 to 1923-12-31 overall overall N (%) years 81 (0.12%)
<=20 overall N (%) years 81 (0.12%)
overall Female N (%) years 46 (0.07%)
Male N (%) years 35 (0.05%)
<=20 Female N (%) years 46 (0.07%)
Male N (%) years 35 (0.05%)
1924-01-01 to 1924-12-31 overall overall N (%) years 76 (0.12%)
<=20 overall N (%) years 76 (0.12%)
overall Female N (%) years 44 (0.07%)
Male N (%) years 32 (0.05%)
<=20 Female N (%) years 44 (0.07%)
Male N (%) years 32 (0.05%)
1925-01-01 to 1925-12-31 overall overall N (%) years 89 (0.14%)
<=20 overall N (%) years 89 (0.14%)
overall Female N (%) years 54 (0.08%)
Male N (%) years 35 (0.05%)
<=20 Female N (%) years 54 (0.08%)
Male N (%) years 35 (0.05%)
1926-01-01 to 1926-12-31 overall overall N (%) years 94 (0.14%)
<=20 overall N (%) years 94 (0.14%)
overall Male N (%) years 42 (0.06%)
Female N (%) years 52 (0.08%)
<=20 Male N (%) years 42 (0.06%)
Female N (%) years 52 (0.08%)
1927-01-01 to 1927-12-31 overall overall N (%) years 90 (0.14%)
<=20 overall N (%) years 90 (0.14%)
overall Female N (%) years 41 (0.06%)
Male N (%) years 49 (0.08%)
<=20 Female N (%) years 41 (0.06%)
Male N (%) years 49 (0.08%)
1928-01-01 to 1928-12-31 overall overall N (%) years 91 (0.14%)
<=20 overall N (%) years 91 (0.14%)
overall Female N (%) years 57 (0.09%)
Male N (%) years 34 (0.05%)
<=20 Female N (%) years 57 (0.09%)
Male N (%) years 34 (0.05%)
1929-01-01 to 1929-12-31 overall overall N (%) years 75 (0.11%)
<=20 overall N (%) years 75 (0.11%)
overall Female N (%) years 47 (0.07%)
Male N (%) years 28 (0.04%)
<=20 Female N (%) years 47 (0.07%)
Male N (%) years 28 (0.04%)
1930-01-01 to 1930-12-31 overall overall N (%) years 70 (0.11%)
>20 overall N (%) years 6 (0.01%)
<=20 overall N (%) years 64 (0.10%)
overall Female N (%) years 35 (0.05%)
Male N (%) years 35 (0.05%)
<=20 Female N (%) years 29 (0.04%)
Male N (%) years 35 (0.05%)
>20 Female N (%) years 6 (0.01%)
1931-01-01 to 1931-12-31 overall overall N (%) years 94 (0.14%)
>20 overall N (%) years 5 (0.01%)
<=20 overall N (%) years 89 (0.14%)
overall Female N (%) years 57 (0.09%)
Male N (%) years 37 (0.06%)
<=20 Female N (%) years 52 (0.08%)
Male N (%) years 37 (0.06%)
>20 Female N (%) years 5 (0.01%)
1932-01-01 to 1932-12-31 overall overall N (%) years 84 (0.13%)
>20 overall N (%) years 3 (0.00%)
<=20 overall N (%) years 81 (0.12%)
overall Male N (%) years 39 (0.06%)
Female N (%) years 45 (0.07%)
>20 Female N (%) years 3 (0.00%)
<=20 Male N (%) years 39 (0.06%)
Female N (%) years 42 (0.06%)
1933-01-01 to 1933-12-31 overall overall N (%) years 88 (0.13%)
<=20 overall N (%) years 75 (0.11%)
>20 overall N (%) years 13 (0.02%)
overall Female N (%) years 47 (0.07%)
Male N (%) years 41 (0.06%)
<=20 Female N (%) years 37 (0.06%)
Male N (%) years 38 (0.06%)
>20 Female N (%) years 10 (0.02%)
Male N (%) years 3 (0.00%)
1934-01-01 to 1934-12-31 overall overall N (%) years 92 (0.14%)
<=20 overall N (%) years 71 (0.11%)
>20 overall N (%) years 21 (0.03%)
overall Male N (%) years 37 (0.06%)
Female N (%) years 55 (0.08%)
>20 Female N (%) years 13 (0.02%)
Male N (%) years 8 (0.01%)
<=20 Male N (%) years 29 (0.04%)
Female N (%) years 42 (0.06%)
1935-01-01 to 1935-12-31 overall overall N (%) years 91 (0.14%)
<=20 overall N (%) years 64 (0.10%)
>20 overall N (%) years 27 (0.04%)
overall Male N (%) years 47 (0.07%)
Female N (%) years 44 (0.07%)
<=20 Male N (%) years 39 (0.06%)
Female N (%) years 25 (0.04%)
>20 Female N (%) years 19 (0.03%)
Male N (%) years 8 (0.01%)
1936-01-01 to 1936-12-31 overall overall N (%) years 131 (0.20%)