Skip to contents

Create a visual table from a summariseTrend() result

Usage

tableTrend(
  result,
  header = "cdm_name",
  hide = "variable_level",
  groupColumn = c("type", "omop_table"),
  type = NULL,
  style = NULL
)

Arguments

result

A summarised_result object (output of summariseTrend()).

header

A vector specifying the elements to include in the header. The order of elements matters, with the first being the topmost header.

hide

Columns to drop from the output table.

groupColumn

Columns to use as group labels, to see options use visOmopResults::tableColumns(result).

type

Type of formatting output table between gt, datatable and reactable. Default is "gt".

style

Defines the visual formatting of the table. This argument can be provided in one of the following ways:

  1. Pre-defined style: Use the name of a built-in style (e.g., "darwin"). See visOmopResults::tableStyle() for available options.

  2. YAML file path: Provide the path to an existing .yml file defining a new style.

  3. List of custome R code: Supply a block of custom R code or a named list describing styles for each table section. This code must be specific to the selected table type.

If style = NULL, the function will use global options (seevisOmopResults::setGlobalTableOptions()) or a _brand.yml file (if found); otherwise, the default style is applied.

Value

A formatted table visualisation.

Examples

# \donttest{
library(OmopSketch)
library(dplyr, warn.conflicts = FALSE)
library(omock)

cdm <- mockCdmFromDataset(datasetName = "GiBleed", source = "duckdb")
#>  Loading bundled GiBleed tables from package data.
#>  Adding drug_strength table.
#>  Creating local <cdm_reference> object.
#>  Inserting <cdm_reference> into duckdb.
#> duckdb keeps downloaded extensions and secrets in a temporary directory:
#>  /tmp/RtmpHDb1h0/duckdb
#> This is removed when the R session ends.
#>  Extensions are re-downloaded each session.
#>  Secrets are lost.
#>  Run duckdb(shared_home = TRUE) (or create ~/.duckdb) to keep them (suitable for most users).
#>  Run duckdb(shared_home = FALSE) to accept the temporary directory (and silence this message).
#>  See ?duckdb_storage for details and alternatives.

result <- summariseTrend(
  cdm = cdm,
  episode = "observation_period",
  event = c("drug_exposure", "condition_occurrence"),
  interval = "years",
  ageGroup = list("<=20" = c(0, 20), ">20" = c(21, Inf)),
  sex = TRUE
)

tableTrend(result = result)
Summary of Number of records, Number of records: end_date, Number of records: start_date by years in condition_occurrence, drug_exposure, observation_period tables
Variable name Time interval Age group Sex Estimate name Interval
Database name
GiBleed
event; condition_occurrence
Number of records 1908-01-01 to 1908-12-31 overall overall N (%) years 1 (0.00%)
<=20 overall N (%) years 1 (0.00%)
overall Female N (%) years 1 (0.00%)
<=20 Female N (%) years 1 (0.00%)
1909-01-01 to 1909-12-31 overall overall N (%) years 4 (0.01%)
<=20 overall N (%) years 4 (0.01%)
overall Female N (%) years 4 (0.01%)
<=20 Female N (%) years 4 (0.01%)
1910-01-01 to 1910-12-31 overall overall N (%) years 16 (0.02%)
<=20 overall N (%) years 16 (0.02%)
overall Female N (%) years 15 (0.02%)
Male N (%) years 1 (0.00%)
<=20 Female N (%) years 15 (0.02%)
Male N (%) years 1 (0.00%)
1911-01-01 to 1911-12-31 overall overall N (%) years 18 (0.03%)
<=20 overall N (%) years 18 (0.03%)
overall Male N (%) years 5 (0.01%)
Female N (%) years 13 (0.02%)
<=20 Female N (%) years 13 (0.02%)
Male N (%) years 5 (0.01%)
1912-01-01 to 1912-12-31 overall overall N (%) years 31 (0.05%)
<=20 overall N (%) years 31 (0.05%)
overall Female N (%) years 26 (0.04%)
Male N (%) years 5 (0.01%)
<=20 Female N (%) years 26 (0.04%)
Male N (%) years 5 (0.01%)
1913-01-01 to 1913-12-31 overall overall N (%) years 38 (0.06%)
<=20 overall N (%) years 38 (0.06%)
overall Male N (%) years 10 (0.02%)
Female N (%) years 28 (0.04%)
<=20 Male N (%) years 10 (0.02%)
Female N (%) years 28 (0.04%)
1914-01-01 to 1914-12-31 overall overall N (%) years 32 (0.05%)
<=20 overall N (%) years 32 (0.05%)
overall Female N (%) years 26 (0.04%)
Male N (%) years 6 (0.01%)
<=20 Male N (%) years 6 (0.01%)
Female N (%) years 26 (0.04%)
1915-01-01 to 1915-12-31 overall overall N (%) years 40 (0.06%)
<=20 overall N (%) years 40 (0.06%)
overall Female N (%) years 24 (0.04%)
Male N (%) years 16 (0.02%)
<=20 Male N (%) years 16 (0.02%)
Female N (%) years 24 (0.04%)
1916-01-01 to 1916-12-31 overall overall N (%) years 41 (0.06%)
<=20 overall N (%) years 41 (0.06%)
overall Female N (%) years 30 (0.05%)
Male N (%) years 11 (0.02%)
<=20 Male N (%) years 11 (0.02%)
Female N (%) years 30 (0.05%)
1917-01-01 to 1917-12-31 overall overall N (%) years 42 (0.06%)
<=20 overall N (%) years 42 (0.06%)
overall Female N (%) years 20 (0.03%)
Male N (%) years 22 (0.03%)
<=20 Male N (%) years 22 (0.03%)
Female N (%) years 20 (0.03%)
1918-01-01 to 1918-12-31 overall overall N (%) years 35 (0.05%)
<=20 overall N (%) years 35 (0.05%)
overall Male N (%) years 13 (0.02%)
Female N (%) years 22 (0.03%)
<=20 Male N (%) years 13 (0.02%)
Female N (%) years 22 (0.03%)
1919-01-01 to 1919-12-31 overall overall N (%) years 43 (0.07%)
<=20 overall N (%) years 43 (0.07%)
overall Male N (%) years 18 (0.03%)
Female N (%) years 25 (0.04%)
<=20 Female N (%) years 25 (0.04%)
Male N (%) years 18 (0.03%)
1920-01-01 to 1920-12-31 overall overall N (%) years 50 (0.08%)
<=20 overall N (%) years 50 (0.08%)
overall Male N (%) years 21 (0.03%)
Female N (%) years 29 (0.04%)
<=20 Male N (%) years 21 (0.03%)
Female N (%) years 29 (0.04%)
1921-01-01 to 1921-12-31 overall overall N (%) years 56 (0.09%)
<=20 overall N (%) years 56 (0.09%)
overall Male N (%) years 17 (0.03%)
Female N (%) years 39 (0.06%)
<=20 Male N (%) years 17 (0.03%)
Female N (%) years 39 (0.06%)
1922-01-01 to 1922-12-31 overall overall N (%) years 61 (0.09%)
<=20 overall N (%) years 61 (0.09%)
overall Female N (%) years 34 (0.05%)
Male N (%) years 27 (0.04%)
<=20 Female N (%) years 34 (0.05%)
Male N (%) years 27 (0.04%)
1923-01-01 to 1923-12-31 overall overall N (%) years 69 (0.11%)
<=20 overall N (%) years 69 (0.11%)
overall Female N (%) years 39 (0.06%)
Male N (%) years 30 (0.05%)
<=20 Male N (%) years 30 (0.05%)
Female N (%) years 39 (0.06%)
1924-01-01 to 1924-12-31 overall overall N (%) years 63 (0.10%)
<=20 overall N (%) years 63 (0.10%)
overall Male N (%) years 25 (0.04%)
Female N (%) years 38 (0.06%)
<=20 Male N (%) years 25 (0.04%)
Female N (%) years 38 (0.06%)
1925-01-01 to 1925-12-31 overall overall N (%) years 76 (0.12%)
<=20 overall N (%) years 76 (0.12%)
overall Male N (%) years 29 (0.04%)
Female N (%) years 47 (0.07%)
<=20 Female N (%) years 47 (0.07%)
Male N (%) years 29 (0.04%)
1926-01-01 to 1926-12-31 overall overall N (%) years 80 (0.12%)
<=20 overall N (%) years 80 (0.12%)
overall Male N (%) years 37 (0.06%)
Female N (%) years 43 (0.07%)
<=20 Female N (%) years 43 (0.07%)
Male N (%) years 37 (0.06%)
1927-01-01 to 1927-12-31 overall overall N (%) years 74 (0.11%)
<=20 overall N (%) years 74 (0.11%)
overall Male N (%) years 41 (0.06%)
Female N (%) years 33 (0.05%)
<=20 Female N (%) years 33 (0.05%)
Male N (%) years 41 (0.06%)
1928-01-01 to 1928-12-31 overall overall N (%) years 75 (0.11%)
<=20 overall N (%) years 75 (0.11%)
overall Male N (%) years 25 (0.04%)
Female N (%) years 50 (0.08%)
<=20 Female N (%) years 50 (0.08%)
Male N (%) years 25 (0.04%)
1929-01-01 to 1929-12-31 overall overall N (%) years 64 (0.10%)
<=20 overall N (%) years 64 (0.10%)
overall Male N (%) years 23 (0.04%)
Female N (%) years 41 (0.06%)
<=20 Female N (%) years 41 (0.06%)
Male N (%) years 23 (0.04%)
1930-01-01 to 1930-12-31 overall overall N (%) years 63 (0.10%)
<=20 overall N (%) years 57 (0.09%)
>20 overall N (%) years 6 (0.01%)
overall Female N (%) years 30 (0.05%)
Male N (%) years 33 (0.05%)
<=20 Female N (%) years 24 (0.04%)
>20 Female N (%) years 6 (0.01%)
<=20 Male N (%) years 33 (0.05%)
1931-01-01 to 1931-12-31 overall overall N (%) years 82 (0.13%)
>20 overall N (%) years 4 (0.01%)
<=20 overall N (%) years 78 (0.12%)
overall Male N (%) years 29 (0.04%)
Female N (%) years 53 (0.08%)
<=20 Female N (%) years 49 (0.08%)
>20 Female N (%) years 4 (0.01%)
<=20 Male N (%) years 29 (0.04%)
1932-01-01 to 1932-12-31 overall overall N (%) years 74 (0.11%)
<=20 overall N (%) years 71 (0.11%)
>20 overall N (%) years 3 (0.00%)
overall Female N (%) years 42 (0.06%)
Male N (%) years 32 (0.05%)
<=20 Female N (%) years 39 (0.06%)
>20 Female N (%) years 3 (0.00%)
<=20 Male N (%) years 32 (0.05%)
1933-01-01 to 1933-12-31 overall overall N (%) years 79 (0.12%)
<=20 overall N (%) years 66 (0.10%)
>20 overall N (%) years 13 (0.02%)
overall Female N (%) years 44 (0.07%)
Male N (%) years 35 (0.05%)
<=20 Female N (%) years 34 (0.05%)
>20 Female N (%) years 10 (0.02%)
Male N (%) years 3 (0.00%)
<=20 Male N (%) years 32 (0.05%)
1934-01-01 to 1934-12-31 overall overall N (%) years 87 (0.13%)
<=20 overall N (%) years 67 (0.10%)
>20 overall N (%) years 20 (0.03%)
overall Male N (%) years 34 (0.05%)
Female N (%) years 53 (0.08%)
<=20 Male N (%) years 26 (0.04%)
Female N (%) years 41 (0.06%)
>20 Female N (%) years 12 (0.02%)
Male N (%) years 8 (0.01%)
1935-01-01 to 1935-12-31 overall overall N (%) years 82 (0.13%)
>20 overall N (%) years 26 (0.04%)
<=20 overall N (%) years 56 (0.09%)
overall Male N (%) years 42 (0.06%)
Female N (%) years 40 (0.06%)
>20 Male N (%) years 8 (0.01%)
<=20 Female N (%) years 22 (0.03%)
>20 Female N (%) years 18 (0.03%)
<=20 Male N (%) years 34 (0.05%)
1936-01-01 to 1936-12-31 overall overall N (%) years 118 (0.18%)
>20 overall N (%) years 26 (0.04%)
<=20 overall N (%) years 92 (0.14%)
overall Female N (%) years 75 (0.11%)
Male N (%) years 43 (0.07%)
<=20 Male N (%) years 34 (0.05%)
>20 Male N (%) years 9 (0.01%)
<=20 Female N (%) years 58 (0.09%)
>20 Female N (%) years 17 (0.03%)
1937-01-01 to 1937-12-31 overall overall N (%) years 119 (0.18%)
<=20 overall N (%) years 96 (0.15%)
>20 overall N (%) years 23 (0.04%)
overall Male N (%) years 51 (0.08%)
Female N (%) years 68 (0.10%)
<=20 Male N (%) years 46 (0.07%)
Female N (%) years 50 (0.08%)
>20 Female N (%) years 18 (0.03%)
Male N (%) years 5 (0.01%)
1938-01-01 to 1938-12-31 overall overall N (%) years 121 (0.19%)
<=20 overall N (%) years 88 (0.13%)
>20 overall N (%) years 33 (0.05%)
overall Male N (%) years 49 (0.08%)
Female N (%) years 72 (0.11%)
<=20 Male N (%) years 44 (0.07%)
Female N (%) years 44 (0.07%)
>20 Female N (%) years 28 (0.04%)
Male N (%) years 5 (0.01%)
1939-01-01 to 1939-12-31 overall overall N (%) years 135 (0.21%)
<=20 overall N (%) years 104 (0.16%)
>20 overall N (%) years 31 (0.05%)
overall Male N (%) years 59 (0.09%)
Female N (%) years 76 (0.12%)
<=20 Male N (%) years 48 (0.07%)
Female N (%) years 56 (0.09%)
>20 Female N (%) years 20 (0.03%)
Male N (%) years 11 (0.02%)
1940-01-01 to 1940-12-31 overall overall N (%) years 148 (0.23%)
<=20 overall N (%) years 126 (0.19%)
>20 overall N (%) years 22 (0.03%)
overall Male N (%) years 74 (0.11%)
Female N (%) years 74 (0.11%)
<=20 Male N (%) years 62 (0.09%)
Female N (%) years 64 (0.10%)
>20 Female N (%) years 10 (0.02%)
Male N (%) years 12 (0.02%)
1941-01-01 to 1941-12-31 overall overall N (%) years 166 (0.25%)
<=20 overall N (%) years 128 (0.20%)
>20 overall N (%) years 38 (0.06%)
overall Female N (%) years 79 (0.12%)
Male N (%) years 87 (0.13%)
<=20 Female N (%) years 59 (0.09%)
>20 Female N (%) years 20 (0.03%)
Male N (%) years 18 (0.03%)
<=20 Male N (%) years 69 (0.11%)
1942-01-01 to 1942-12-31 overall overall N (%) years 167 (0.26%)
>20 overall N (%) years 47 (0.07%)
<=20 overall N (%) years 120 (0.18%)
overall Female N (%) years 87 (0.13%)
Male N (%) years 80 (0.12%)
<=20 Male N (%) years 61 (0.09%)
>20 Male N (%) years 19 (0.03%)
Female N (%) years 28 (0.04%)
<=20 Female N (%) years 59 (0.09%)
1943-01-01 to 1943-12-31 overall overall N (%) years 191 (0.29%)
<=20 overall N (%) years 131 (0.20%)
>20 overall N (%) years 60 (0.09%)
overall Female N (%) years 103 (0.16%)
Male N (%) years 88 (0.13%)
<=20 Female N (%) years 63 (0.10%)
>20 Female N (%) years 40 (0.06%)
Male N (%) years 20 (0.03%)
<=20 Male N (%) years 68 (0.10%)
1944-01-01 to 1944-12-31 overall overall N (%) years 213 (0.33%)
>20 overall N (%) years 61 (0.09%)
<=20 overall N (%) years 152 (0.23%)
overall Female N (%) years 114 (0.17%)
Male N (%) years 99 (0.15%)
<=20 Male N (%) years 70 (0.11%)
>20 Male N (%) years 29 (0.04%)
Female N (%) years 32 (0.05%)
<=20 Female N (%) years 82 (0.13%)
1945-01-01 to 1945-12-31 overall overall N (%) years 209 (0.32%)
<=20 overall N (%) years 160 (0.24%)
>20 overall N (%) years 49 (0.08%)
overall Male N (%) years 105 (0.16%)
Female N (%) years 104 (0.16%)
<=20 Male N (%) years 86 (0.13%)
Female N (%) years 74 (0.11%)
>20 Female N (%) years 30 (0.05%)
Male N (%) years 19 (0.03%)
1946-01-01 to 1946-12-31 overall overall N (%) years 234 (0.36%)
<=20 overall N (%) years 167 (0.26%)
>20 overall N (%) years 67 (0.10%)
overall Female N (%) years 133 (0.20%)
Male N (%) years 101 (0.15%)
<=20 Female N (%) years 89 (0.14%)
>20 Female N (%) years 44 (0.07%)
Male N (%) years 23 (0.04%)
<=20 Male N (%) years 78 (0.12%)
1947-01-01 to 1947-12-31 overall overall N (%) years 292 (0.45%)
>20 overall N (%) years 80 (0.12%)
<=20 overall N (%) years 212 (0.32%)
overall Female N (%) years 149 (0.23%)
Male N (%) years 143 (0.22%)
<=20 Male N (%) years 111 (0.17%)
>20 Male N (%) years 32 (0.05%)
Female N (%) years 48 (0.07%)
<=20 Female N (%) years 101 (0.15%)
1948-01-01 to 1948-12-31 overall overall N (%) years 273 (0.42%)
>20 overall N (%) years 79 (0.12%)
<=20 overall N (%) years 194 (0.30%)
overall Male N (%) years 127 (0.19%)
Female N (%) years 146 (0.22%)
>20 Male N (%) years 36 (0.06%)
<=20 Female N (%) years 103 (0.16%)
>20 Female N (%) years 43 (0.07%)
<=20 Male N (%) years 91 (0.14%)
1949-01-01 to 1949-12-31 overall overall N (%) years 313 (0.48%)
>20 overall N (%) years 62 (0.09%)
<=20 overall N (%) years 251 (0.38%)
overall Female N (%) years 168 (0.26%)
Male N (%) years 145 (0.22%)
<=20 Male N (%) years 124 (0.19%)
>20 Male N (%) years 21 (0.03%)
<=20 Female N (%) years 127 (0.19%)
>20 Female N (%) years 41 (0.06%)
1950-01-01 to 1950-12-31 overall overall N (%) years 332 (0.51%)
>20 overall N (%) years 64 (0.10%)
<=20 overall N (%) years 268 (0.41%)
overall Male N (%) years 172 (0.26%)
Female N (%) years 160 (0.24%)
>20 Male N (%) years 29 (0.04%)
<=20 Female N (%) years 125 (0.19%)
>20 Female N (%) years 35 (0.05%)
<=20 Male N (%) years 143 (0.22%)
1951-01-01 to 1951-12-31 overall overall N (%) years 334 (0.51%)
<=20 overall N (%) years 281 (0.43%)
>20 overall N (%) years 53 (0.08%)
overall Female N (%) years 167 (0.26%)
Male N (%) years 167 (0.26%)
<=20 Female N (%) years 136 (0.21%)
>20 Female N (%) years 31 (0.05%)
Male N (%) years 22 (0.03%)
<=20 Male N (%) years 145 (0.22%)
1952-01-01 to 1952-12-31 overall overall N (%) years 425 (0.65%)
>20 overall N (%) years 79 (0.12%)
<=20 overall N (%) years 346 (0.53%)
overall Female N (%) years 216 (0.33%)
Male N (%) years 209 (0.32%)
<=20 Male N (%) years 181 (0.28%)
>20 Male N (%) years 28 (0.04%)
Female N (%) years 51 (0.08%)
<=20 Female N (%) years 165 (0.25%)
1953-01-01 to 1953-12-31 overall overall N (%) years 408 (0.62%)
<=20 overall N (%) years 326 (0.50%)
>20 overall N (%) years 82 (0.13%)
overall Female N (%) years 213 (0.33%)
Male N (%) years 195 (0.30%)
<=20 Female N (%) years 160 (0.24%)
>20 Female N (%) years 53 (0.08%)
Male N (%) years 29 (0.04%)
<=20 Male N (%) years 166 (0.25%)
1954-01-01 to 1954-12-31 overall overall N (%) years 422 (0.65%)
>20 overall N (%) years 75 (0.11%)
<=20 overall N (%) years 347 (0.53%)
overall Male N (%) years 207 (0.32%)
Female N (%) years 215 (0.33%)
>20 Male N (%) years 29 (0.04%)
<=20 Female N (%) years 169 (0.26%)
>20 Female N (%) years 46 (0.07%)
<=20 Male N (%) years 178 (0.27%)
1955-01-01 to 1955-12-31 overall overall N (%) years 458 (0.70%)
<=20 overall N (%) years 374 (0.57%)
>20 overall N (%) years 84 (0.13%)
overall Female N (%) years 236 (0.36%)
Male N (%) years 222 (0.34%)
<=20 Female N (%) years 190 (0.29%)
>20 Female N (%) years 46 (0.07%)
Male N (%) years 38 (0.06%)
<=20 Male N (%) years 184 (0.28%)
1956-01-01 to 1956-12-31 overall overall N (%) years 458 (0.70%)
>20 overall N (%) years 91 (0.14%)
<=20 overall N (%) years 367 (0.56%)
overall Male N (%) years 194 (0.30%)
Female N (%) years 264 (0.40%)
>20 Male N (%) years 34 (0.05%)
<=20 Female N (%) years 207 (0.32%)
>20 Female N (%) years 57 (0.09%)
<=20 Male N (%) years 160 (0.24%)
1957-01-01 to 1957-12-31 overall overall N (%) years 484 (0.74%)
>20 overall N (%) years 93 (0.14%)
<=20 overall N (%) years 391 (0.60%)
overall Male N (%) years 237 (0.36%)
Female N (%) years 247 (0.38%)
>20 Male N (%) years 44 (0.07%)
<=20 Female N (%) years 198 (0.30%)
>20 Female N (%) years 49 (0.08%)
<=20 Male N (%) years 193 (0.30%)
1958-01-01 to 1958-12-31 overall overall N (%) years 543 (0.83%)
>20 overall N (%) years 112 (0.17%)
<=20 overall N (%) years 431 (0.66%)
overall Male N (%) years 279 (0.43%)
Female N (%) years 264 (0.40%)
>20 Male N (%) years 51 (0.08%)
<=20 Female N (%) years 203 (0.31%)
>20 Female N (%) years 61 (0.09%)
<=20 Male N (%) years 228 (0.35%)
1959-01-01 to 1959-12-31 overall overall N (%) years 557 (0.85%)
>20 overall N (%) years 108 (0.17%)
<=20 overall N (%) years 449 (0.69%)
overall Male N (%) years 271 (0.41%)
Female N (%) years 286 (0.44%)
>20 Male N (%) years 44 (0.07%)
Female N (%) years 64 (0.10%)
<=20 Female N (%) years 222 (0.34%)
Male N (%) years 227 (0.35%)
1960-01-01 to 1960-12-31 overall overall N (%) years 554 (0.85%)
>20 overall N (%) years 124 (0.19%)
<=20 overall N (%) years 430 (0.66%)
overall Male N (%) years 279 (0.43%)
Female N (%) years 275 (0.42%)
>20 Male N (%) years 57 (0.09%)
Female N (%) years 67 (0.10%)
<=20 Female N (%) years 208 (0.32%)
Male N (%) years 222 (0.34%)
1961-01-01 to 1961-12-31 overall overall N (%) years 612 (0.94%)
<=20 overall N (%) years 482 (0.74%)
>20 overall N (%) years 130 (0.20%)
overall Male N (%) years 305 (0.47%)
Female N (%) years 307 (0.47%)
<=20 Male N (%) years 252 (0.39%)
Female N (%) years 230 (0.35%)
>20 Female N (%) years 77 (0.12%)
Male N (%) years 53 (0.08%)
1962-01-01 to 1962-12-31 overall overall N (%) years 650 (0.99%)
>20 overall N (%) years 129 (0.20%)
<=20 overall N (%) years 521 (0.80%)
overall Male N (%) years 320 (0.49%)
Female N (%) years 330 (0.51%)
>20 Male N (%) years 59 (0.09%)
<=20 Female N (%) years 260 (0.40%)
>20 Female N (%) years 70 (0.11%)
<=20 Male N (%) years 261 (0.40%)
1963-01-01 to 1963-12-31 overall overall N (%) years 649 (0.99%)
<=20 overall N (%) years 516 (0.79%)
>20 overall N (%) years 133 (0.20%)
overall Male N (%) years 337 (0.52%)
Female N (%) years 312 (0.48%)
<=20 Male N (%) years 270 (0.41%)
Female N (%) years 246 (0.38%)
>20 Female N (%) years 66 (0.10%)
Male N (%) years 67 (0.10%)
1964-01-01 to 1964-12-31 overall overall N (%) years 719 (1.10%)
<=20 overall N (%) years 556 (0.85%)
>20 overall N (%) years 163 (0.25%)
overall Female N (%) years 369 (0.56%)
Male N (%) years 350 (0.54%)
>20 Female N (%) years 94 (0.14%)
<=20 Female N (%) years 275 (0.42%)
>20 Male N (%) years 69 (0.11%)
<=20 Male N (%) years 281 (0.43%)
1965-01-01 to 1965-12-31 overall overall N (%) years 721 (1.10%)
<=20 overall N (%) years 562 (0.86%)
>20 overall N (%) years 159 (0.24%)
overall Male N (%) years 363 (0.56%)
Female N (%) years 358 (0.55%)
<=20 Male N (%) years 288 (0.44%)
Female N (%) years 274 (0.42%)
>20 Female N (%) years 84 (0.13%)
Male N (%) years 75 (0.11%)
1966-01-01 to 1966-12-31 overall overall N (%) years 753 (1.15%)
>20 overall N (%) years 183 (0.28%)
<=20 overall N (%) years 570 (0.87%)
overall Male N (%) years 352 (0.54%)
Female N (%) years 401 (0.61%)
>20 Male N (%) years 74 (0.11%)
<=20 Female N (%) years 292 (0.45%)
>20 Female N (%) years 109 (0.17%)
<=20 Male N (%) years 278 (0.43%)
1967-01-01 to 1967-12-31 overall overall N (%) years 805 (1.23%)
>20 overall N (%) years 197 (0.30%)
<=20 overall N (%) years 608 (0.93%)
overall Male N (%) years 392 (0.60%)
Female N (%) years 413 (0.63%)
>20 Male N (%) years 90 (0.14%)
<=20 Female N (%) years 306 (0.47%)
>20 Female N (%) years 107 (0.16%)
<=20 Male N (%) years 302 (0.46%)
1968-01-01 to 1968-12-31 overall overall N (%) years 853 (1.31%)
>20 overall N (%) years 214 (0.33%)
<=20 overall N (%) years 639 (0.98%)
overall Female N (%) years 441 (0.68%)
Male N (%) years 412 (0.63%)
<=20 Male N (%) years 329 (0.50%)
>20 Male N (%) years 83 (0.13%)
Female N (%) years 131 (0.20%)
<=20 Female N (%) years 310 (0.47%)
1969-01-01 to 1969-12-31 overall overall N (%) years 814 (1.25%)
>20 overall N (%) years 217 (0.33%)
<=20 overall N (%) years 597 (0.91%)
overall Male N (%) years 380 (0.58%)
Female N (%) years 434 (0.66%)
>20 Male N (%) years 96 (0.15%)
Female N (%) years 121 (0.19%)
<=20 Female N (%) years 313 (0.48%)
Male N (%) years 284 (0.43%)
1970-01-01 to 1970-12-31 overall overall N (%) years 823 (1.26%)
<=20 overall N (%) years 593 (0.91%)
>20 overall N (%) years 230 (0.35%)
overall Male N (%) years 407 (0.62%)
Female N (%) years 416 (0.64%)
<=20 Male N (%) years 292 (0.45%)
Female N (%) years 301 (0.46%)
>20 Female N (%) years 115 (0.18%)
Male N (%) years 115 (0.18%)
1971-01-01 to 1971-12-31 overall overall N (%) years 883 (1.35%)
>20 overall N (%) years 280 (0.43%)
<=20 overall N (%) years 603 (0.92%)
overall Male N (%) years 438 (0.67%)
Female N (%) years 445 (0.68%)
>20 Male N (%) years 129 (0.20%)
<=20 Female N (%) years 294 (0.45%)
>20 Female N (%) years 151 (0.23%)
<=20 Male N (%) years 309 (0.47%)
1972-01-01 to 1972-12-31 overall overall N (%) years 878 (1.34%)
<=20 overall N (%) years 604 (0.92%)
>20 overall N (%) years 274 (0.42%)
overall Male N (%) years 414 (0.63%)
Female N (%) years 464 (0.71%)
<=20 Male N (%) years 289 (0.44%)
>20 Female N (%) years 149 (0.23%)
<=20 Female N (%) years 315 (0.48%)
>20 Male N (%) years 125 (0.19%)
1973-01-01 to 1973-12-31 overall overall N (%) years 992 (1.52%)
>20 overall N (%) years 286 (0.44%)
<=20 overall N (%) years 706 (1.08%)
overall Male N (%) years 489 (0.75%)
Female N (%) years 503 (0.77%)
>20 Male N (%) years 149 (0.23%)
Female N (%) years 137 (0.21%)
<=20 Female N (%) years 366 (0.56%)
Male N (%) years 340 (0.52%)
1974-01-01 to 1974-12-31 overall overall N (%) years 954 (1.46%)
>20 overall N (%) years 303 (0.46%)
<=20 overall N (%) years 651 (1.00%)
overall Male N (%) years 485 (0.74%)
Female N (%) years 469 (0.72%)
>20 Male N (%) years 139 (0.21%)
Female N (%) years 164 (0.25%)
<=20 Female N (%) years 305 (0.47%)
Male N (%) years 346 (0.53%)
1975-01-01 to 1975-12-31 overall overall N (%) years 978 (1.50%)
<=20 overall N (%) years 621 (0.95%)
>20 overall N (%) years 357 (0.55%)
overall Female N (%) years 487 (0.75%)
Male N (%) years 491 (0.75%)
<=20 Female N (%) years 320 (0.49%)
>20 Female N (%) years 167 (0.26%)
Male N (%) years 190 (0.29%)
<=20 Male N (%) years 301 (0.46%)
1976-01-01 to 1976-12-31 overall overall N (%) years 950 (1.45%)
<=20 overall N (%) years 594 (0.91%)
>20 overall N (%) years 356 (0.54%)
overall Male N (%) years 466 (0.71%)
Female N (%) years 484 (0.74%)
<=20 Male N (%) years 307 (0.47%)
Female N (%) years 287 (0.44%)
>20 Female N (%) years 197 (0.30%)
Male N (%) years 159 (0.24%)
1977-01-01 to 1977-12-31 overall overall N (%) years 985 (1.51%)
>20 overall N (%) years 395 (0.60%)
<=20 overall N (%) years 590 (0.90%)
overall Female N (%) years 496 (0.76%)
Male N (%) years 489 (0.75%)
<=20 Male N (%) years 301 (0.46%)
>20 Male N (%) years 188 (0.29%)
Female N (%) years 207 (0.32%)
<=20 Female N (%) years 289 (0.44%)
1978-01-01 to 1978-12-31 overall overall N (%) years 1,117 (1.71%)
<=20 overall N (%) years 668 (1.02%)
>20 overall N (%) years 449 (0.69%)
overall Male N (%) years 536 (0.82%)
Female N (%) years 581 (0.89%)
<=20 Male N (%) years 330 (0.51%)
>20 Female N (%) years 243 (0.37%)
<=20 Female N (%) years 338 (0.52%)
>20 Male N (%) years 206 (0.32%)
1979-01-01 to 1979-12-31 overall overall N (%) years 1,089 (1.67%)
<=20 overall N (%) years 632 (0.97%)
>20 overall N (%) years 457 (0.70%)
overall Female N (%) years 555 (0.85%)
Male N (%) years 534 (0.82%)
>20 Female N (%) years 230 (0.35%)
<=20 Female N (%) years 325 (0.50%)
>20 Male N (%) years 227 (0.35%)
<=20 Male N (%) years 307 (0.47%)
1980-01-01 to 1980-12-31 overall overall N (%) years 1,076 (1.65%)
>20 overall N (%) years 509 (0.78%)
<=20 overall N (%) years 567 (0.87%)
overall Male N (%) years 535 (0.82%)
Female N (%) years 541 (0.83%)
>20 Male N (%) years 261 (0.40%)
<=20 Female N (%) years 293 (0.45%)
>20 Female N (%) years 248 (0.38%)
<=20 Male N (%) years 274 (0.42%)
1981-01-01 to 1981-12-31 overall overall N (%) years 1,063 (1.63%)
<=20 overall N (%) years 565 (0.86%)
>20 overall N (%) years 498 (0.76%)
overall Male N (%) years 493 (0.75%)
Female N (%) years 570 (0.87%)
<=20 Male N (%) years 260 (0.40%)
Female N (%) years 305 (0.47%)
>20 Female N (%) years 265 (0.41%)
Male N (%) years 233 (0.36%)
1982-01-01 to 1982-12-31 overall overall N (%) years 1,039 (1.59%)
<=20 overall N (%) years 501 (0.77%)
>20 overall N (%) years 538 (0.82%)
overall Female N (%) years 540 (0.83%)
Male N (%) years 499 (0.76%)
>20 Female N (%) years 275 (0.42%)
<=20 Female N (%) years 265 (0.41%)
>20 Male N (%) years 263 (0.40%)
<=20 Male N (%) years 236 (0.36%)
1983-01-01 to 1983-12-31 overall overall N (%) years 1,040 (1.59%)
<=20 overall N (%) years 488 (0.75%)
>20 overall N (%) years 552 (0.84%)
overall Male N (%) years 490 (0.75%)
Female N (%) years 550 (0.84%)
<=20 Male N (%) years 231 (0.35%)
Female N (%) years 257 (0.39%)
>20 Female N (%) years 293 (0.45%)
Male N (%) years 259 (0.40%)
1984-01-01 to 1984-12-31 overall overall N (%) years 1,070 (1.64%)
>20 overall N (%) years 579 (0.89%)
<=20 overall N (%) years 491 (0.75%)
overall Female N (%) years 552 (0.84%)
Male N (%) years 518 (0.79%)
<=20 Male N (%) years 234 (0.36%)
>20 Male N (%) years 284 (0.43%)
<=20 Female N (%) years 257 (0.39%)
>20 Female N (%) years 295 (0.45%)
1985-01-01 to 1985-12-31 overall overall N (%) years 1,025 (1.57%)
>20 overall N (%) years 592 (0.91%)
<=20 overall N (%) years 433 (0.66%)
overall Male N (%) years 491 (0.75%)
Female N (%) years 534 (0.82%)
>20 Male N (%) years 276 (0.42%)
Female N (%) years 316 (0.48%)
<=20 Female N (%) years 218 (0.33%)
Male N (%) years 215 (0.33%)
1986-01-01 to 1986-12-31 overall overall N (%) years 1,051 (1.61%)
>20 overall N (%) years 650 (0.99%)
<=20 overall N (%) years 401 (0.61%)
overall Male N (%) years 488 (0.75%)
Female N (%) years 563 (0.86%)
>20 Male N (%) years 301 (0.46%)
<=20 Female N (%) years 214 (0.33%)
>20 Female N (%) years 349 (0.53%)
<=20 Male N (%) years 187 (0.29%)
1987-01-01 to 1987-12-31 overall overall N (%) years 1,053 (1.61%)
<=20 overall N (%) years 381 (0.58%)
>20 overall N (%) years 672 (1.03%)
overall Female N (%) years 552 (0.84%)
Male N (%) years 501 (0.77%)
>20 Female N (%) years 362 (0.55%)
<=20 Female N (%) years 190 (0.29%)
>20 Male N (%) years 310 (0.47%)
<=20 Male N (%) years 191 (0.29%)
1988-01-01 to 1988-12-31 overall overall N (%) years 960 (1.47%)
>20 overall N (%) years 632 (0.97%)
<=20 overall N (%) years 328 (0.50%)
overall Male N (%) years 478 (0.73%)
Female N (%) years 482 (0.74%)
>20 Male N (%) years 316 (0.48%)
Female N (%) years 316 (0.48%)
<=20 Female N (%) years 166 (0.25%)
Male N (%) years 162 (0.25%)
1989-01-01 to 1989-12-31 overall overall N (%) years 1,022 (1.56%)
<=20 overall N (%) years 293 (0.45%)
>20 overall N (%) years 729 (1.12%)
overall Female N (%) years 566 (0.87%)
Male N (%) years 456 (0.70%)
>20 Female N (%) years 394 (0.60%)
<=20 Female N (%) years 172 (0.26%)
>20 Male N (%) years 335 (0.51%)
<=20 Male N (%) years 121 (0.19%)
1990-01-01 to 1990-12-31 overall overall N (%) years 1,034 (1.58%)
<=20 overall N (%) years 285 (0.44%)
>20 overall N (%) years 749 (1.15%)
overall Male N (%) years 484 (0.74%)
Female N (%) years 550 (0.84%)
<=20 Male N (%) years 138 (0.21%)
>20 Female N (%) years 403 (0.62%)
<=20 Female N (%) years 147 (0.23%)
>20 Male N (%) years 346 (0.53%)
1991-01-01 to 1991-12-31 overall overall N (%) years 989 (1.51%)
>20 overall N (%) years 754 (1.15%)
<=20 overall N (%) years 235 (0.36%)
overall Female N (%) years 494 (0.76%)
Male N (%) years 495 (0.76%)
<=20 Male N (%) years 111 (0.17%)
>20 Male N (%) years 384 (0.59%)
Female N (%) years 370 (0.57%)
<=20 Female N (%) years 124 (0.19%)
1992-01-01 to 1992-12-31 overall overall N (%) years 990 (1.52%)
<=20 overall N (%) years 213 (0.33%)
>20 overall N (%) years 777 (1.19%)
overall Male N (%) years 484 (0.74%)
Female N (%) years 506 (0.77%)
<=20 Male N (%) years 101 (0.15%)
>20 Female N (%) years 394 (0.60%)
<=20 Female N (%) years 112 (0.17%)
>20 Male N (%) years 383 (0.59%)
1993-01-01 to 1993-12-31 overall overall N (%) years 1,054 (1.61%)
>20 overall N (%) years 857 (1.31%)
<=20 overall N (%) years 197 (0.30%)
overall Male N (%) years 522 (0.80%)
Female N (%) years 532 (0.81%)
>20 Male N (%) years 429 (0.66%)
Female N (%) years 428 (0.66%)
<=20 Female N (%) years 104 (0.16%)
Male N (%) years 93 (0.14%)
1994-01-01 to 1994-12-31 overall overall N (%) years 997 (1.53%)
>20 overall N (%) years 830 (1.27%)
<=20 overall N (%) years 167 (0.26%)
overall Female N (%) years 500 (0.77%)
Male N (%) years 497 (0.76%)
<=20 Male N (%) years 84 (0.13%)
>20 Male N (%) years 413 (0.63%)
Female N (%) years 417 (0.64%)
<=20 Female N (%) years 83 (0.13%)
1995-01-01 to 1995-12-31 overall overall N (%) years 1,077 (1.65%)
>20 overall N (%) years 928 (1.42%)
<=20 overall N (%) years 149 (0.23%)
overall Male N (%) years 543 (0.83%)
Female N (%) years 534 (0.82%)
>20 Male N (%) years 470 (0.72%)
Female N (%) years 458 (0.70%)
<=20 Female N (%) years 76 (0.12%)
Male N (%) years 73 (0.11%)
1996-01-01 to 1996-12-31 overall overall N (%) years 1,008 (1.54%)
>20 overall N (%) years 893 (1.37%)
<=20 overall N (%) years 115 (0.18%)
overall Male N (%) years 486 (0.74%)
Female N (%) years 522 (0.80%)
>20 Male N (%) years 436 (0.67%)
Female N (%) years 457 (0.70%)
<=20 Female N (%) years 65 (0.10%)
Male N (%) years 50 (0.08%)
1997-01-01 to 1997-12-31 overall overall N (%) years 1,059 (1.62%)
>20 overall N (%) years 954 (1.46%)
<=20 overall N (%) years 105 (0.16%)
overall Male N (%) years 503 (0.77%)
Female N (%) years 556 (0.85%)
>20 Male N (%) years 459 (0.70%)
Female N (%) years 495 (0.76%)
<=20 Female N (%) years 61 (0.09%)
Male N (%) years 44 (0.07%)
1998-01-01 to 1998-12-31 overall overall N (%) years 1,045 (1.60%)
>20 overall N (%) years 949 (1.45%)
<=20 overall N (%) years 96 (0.15%)
overall Male N (%) years 498 (0.76%)
Female N (%) years 547 (0.84%)
>20 Male N (%) years 456 (0.70%)
Female N (%) years 493 (0.75%)
<=20 Female N (%) years 54 (0.08%)
Male N (%) years 42 (0.06%)
1999-01-01 to 1999-12-31 overall overall N (%) years 1,055 (1.61%)
>20 overall N (%) years 999 (1.53%)
<=20 overall N (%) years 56 (0.09%)
overall Female N (%) years 543 (0.83%)
Male N (%) years 512 (0.78%)
<=20 Male N (%) years 28 (0.04%)
>20 Male N (%) years 484 (0.74%)
Female N (%) years 515 (0.79%)
<=20 Female N (%) years 28 (0.04%)
2000-01-01 to 2000-12-31 overall overall N (%) years 1,053 (1.61%)
<=20 overall N (%) years 44 (0.07%)
>20 overall N (%) years 1,009 (1.54%)
overall Male N (%) years 503 (0.77%)
Female N (%) years 550 (0.84%)
<=20 Male N (%) years 22 (0.03%)
>20 Female N (%) years 528 (0.81%)
<=20 Female N (%) years 22 (0.03%)
>20 Male N (%) years 481 (0.74%)
2001-01-01 to 2001-12-31 overall overall N (%) years 970 (1.48%)
>20 overall N (%) years 942 (1.44%)
<=20 overall N (%) years 28 (0.04%)
overall Male N (%) years 444 (0.68%)
Female N (%) years 526 (0.81%)
>20 Male N (%) years 434 (0.66%)
Female N (%) years 508 (0.78%)
<=20 Female N (%) years 18 (0.03%)
Male N (%) years 10 (0.02%)
2002-01-01 to 2002-12-31 overall overall N (%) years 1,006 (1.54%)
>20 overall N (%) years 983 (1.50%)
<=20 overall N (%) years 23 (0.04%)
overall Female N (%) years 498 (0.76%)
Male N (%) years 508 (0.78%)
<=20 Male N (%) years 15 (0.02%)
>20 Male N (%) years 493 (0.75%)
Female N (%) years 490 (0.75%)
<=20 Female N (%) years 8 (0.01%)
2003-01-01 to 2003-12-31 overall overall N (%) years 959 (1.47%)
<=20 overall N (%) years 7 (0.01%)
>20 overall N (%) years 952 (1.46%)
overall Male N (%) years 474 (0.73%)
Female N (%) years 485 (0.74%)
<=20 Male N (%) years 2 (0.00%)
>20 Female N (%) years 480 (0.73%)
<=20 Female N (%) years 5 (0.01%)
>20 Male N (%) years 472 (0.72%)
2004-01-01 to 2004-12-31 overall overall N (%) years 1,054 (1.61%)
<=20 overall N (%) years 10 (0.02%)
>20 overall N (%) years 1,044 (1.60%)
overall Female N (%) years 532 (0.81%)
Male N (%) years 522 (0.80%)
>20 Female N (%) years 527 (0.81%)
<=20 Female N (%) years 5 (0.01%)
>20 Male N (%) years 517 (0.79%)
<=20 Male N (%) years 5 (0.01%)
2005-01-01 to 2005-12-31 overall overall N (%) years 1,015 (1.55%)
>20 overall N (%) years 1,012 (1.55%)
<=20 overall N (%) years 3 (0.00%)
overall Male N (%) years 491 (0.75%)
Female N (%) years 524 (0.80%)
>20 Male N (%) years 490 (0.75%)
Female N (%) years 522 (0.80%)
<=20 Female N (%) years 2 (0.00%)
Male N (%) years 1 (0.00%)
2006-01-01 to 2006-12-31 overall overall N (%) years 989 (1.51%)
>20 overall N (%) years 988 (1.51%)
<=20 overall N (%) years 1 (0.00%)
overall Female N (%) years 514 (0.79%)
Male N (%) years 475 (0.73%)
>20 Male N (%) years 475 (0.73%)
Female N (%) years 513 (0.79%)
<=20 Female N (%) years 1 (0.00%)
2007-01-01 to 2007-12-31 overall overall N (%) years 1,002 (1.53%)
>20 overall N (%) years 1,002 (1.53%)
overall Female N (%) years 499 (0.76%)
Male N (%) years 503 (0.77%)
>20 Male N (%) years 503 (0.77%)
Female N (%) years 499 (0.76%)
2008-01-01 to 2008-12-31 overall overall N (%) years 1,049 (1.61%)
>20 overall N (%) years 1,049 (1.61%)
overall Male N (%) years 516 (0.79%)
Female N (%) years 533 (0.82%)
>20 Male N (%) years 516 (0.79%)
Female N (%) years 533 (0.82%)
2009-01-01 to 2009-12-31 overall overall N (%) years 973 (1.49%)
>20 overall N (%) years 973 (1.49%)
overall Male N (%) years 461 (0.71%)
Female N (%) years 512 (0.78%)
>20 Female N (%) years 512 (0.78%)
Male N (%) years 461 (0.71%)
2010-01-01 to 2010-12-31 overall overall N (%) years 979 (1.50%)
>20 overall N (%) years 979 (1.50%)
overall Male N (%) years 487 (0.75%)
Female N (%) years 492 (0.75%)
>20 Female N (%) years 492 (0.75%)
Male N (%) years 487 (0.75%)
2011-01-01 to 2011-12-31 overall overall N (%) years 967 (1.48%)
>20 overall N (%) years 967 (1.48%)
overall Female N (%) years 488 (0.75%)
Male N (%) years 479 (0.73%)
>20 Female N (%) years 488 (0.75%)
Male N (%) years 479 (0.73%)
2012-01-01 to 2012-12-31 overall overall N (%) years 988 (1.51%)
>20 overall N (%) years 988 (1.51%)
overall Female N (%) years 496 (0.76%)
Male N (%) years 492 (0.75%)
>20 Female N (%) years 496 (0.76%)
Male N (%) years 492 (0.75%)
2013-01-01 to 2013-12-31 overall overall N (%) years 943 (1.44%)
>20 overall N (%) years 943 (1.44%)
overall Male N (%) years 449 (0.69%)
Female N (%) years 494 (0.76%)
>20 Female N (%) years 494 (0.76%)
Male N (%) years 449 (0.69%)
2014-01-01 to 2014-12-31 overall overall N (%) years 981 (1.50%)
>20 overall N (%) years 981 (1.50%)
overall Female N (%) years 523 (0.80%)
Male N (%) years 458 (0.70%)
>20 Male N (%) years 458 (0.70%)
Female N (%) years 523 (0.80%)
2015-01-01 to 2015-12-31 overall overall N (%) years 933 (1.43%)
>20 overall N (%) years 933 (1.43%)
overall Male N (%) years 445 (0.68%)
Female N (%) years 488 (0.75%)
>20 Female N (%) years 488 (0.75%)
Male N (%) years 445 (0.68%)
2016-01-01 to 2016-12-31 overall overall N (%) years 1,001 (1.53%)
>20 overall N (%) years 1,001 (1.53%)
overall Male N (%) years 476 (0.73%)
Female N (%) years 525 (0.80%)
>20 Female N (%) years 525 (0.80%)
Male N (%) years 476 (0.73%)
2017-01-01 to 2017-12-31 overall overall N (%) years 998 (1.53%)
>20 overall N (%) years 998 (1.53%)
overall Female N (%) years 501 (0.77%)
Male N (%) years 497 (0.76%)
>20 Female N (%) years 501 (0.77%)
Male N (%) years 497 (0.76%)
2018-01-01 to 2018-12-31 overall overall N (%) years 956 (1.46%)
>20 overall N (%) years 956 (1.46%)
overall Male N (%) years 487 (0.75%)
Female N (%) years 469 (0.72%)
>20 Male N (%) years 487 (0.75%)
Female N (%) years 469 (0.72%)
2019-01-01 to 2019-12-31 overall overall N (%) years 434 (0.66%)
>20 overall N (%) years 434 (0.66%)
overall Male N (%) years 218 (0.33%)
Female N (%) years 216 (0.33%)
>20 Female N (%) years 216 (0.33%)
Male N (%) years 218 (0.33%)
overall overall overall N (%) years 65,332 (100.00%)
>20 overall N (%) years 40,402 (61.84%)
<=20 overall N (%) years 24,930 (38.16%)
overall Male N (%) years 31,588 (48.35%)
Female N (%) years 33,744 (51.65%)
>20 Male N (%) years 19,404 (29.70%)
Female N (%) years 20,998 (32.14%)
<=20 Female N (%) years 12,746 (19.51%)
Male N (%) years 12,184 (18.65%)
event; drug_exposure
Number of records 1909-01-01 to 1909-12-31 overall overall N (%) years 4 (0.01%)
<=20 overall N (%) years 4 (0.01%)
overall Female N (%) years 4 (0.01%)
<=20 Female N (%) years 4 (0.01%)
1910-01-01 to 1910-12-31 overall overall N (%) years 11 (0.02%)
<=20 overall N (%) years 11 (0.02%)
overall Male N (%) years 1 (0.00%)
Female N (%) years 10 (0.01%)
<=20 Male N (%) years 1 (0.00%)
Female N (%) years 10 (0.01%)
1911-01-01 to 1911-12-31 overall overall N (%) years 11 (0.02%)
<=20 overall N (%) years 11 (0.02%)
overall Female N (%) years 9 (0.01%)
Male N (%) years 2 (0.00%)
<=20 Male N (%) years 2 (0.00%)
Female N (%) years 9 (0.01%)
1912-01-01 to 1912-12-31 overall overall N (%) years 22 (0.03%)
<=20 overall N (%) years 22 (0.03%)
overall Male N (%) years 4 (0.01%)
Female N (%) years 18 (0.03%)
<=20 Male N (%) years 4 (0.01%)
Female N (%) years 18 (0.03%)
1913-01-01 to 1913-12-31 overall overall N (%) years 26 (0.04%)
<=20 overall N (%) years 26 (0.04%)
overall Female N (%) years 20 (0.03%)
Male N (%) years 6 (0.01%)
<=20 Female N (%) years 20 (0.03%)
Male N (%) years 6 (0.01%)
1914-01-01 to 1914-12-31 overall overall N (%) years 26 (0.04%)
<=20 overall N (%) years 26 (0.04%)
overall Male N (%) years 6 (0.01%)
Female N (%) years 20 (0.03%)
<=20 Female N (%) years 20 (0.03%)
Male N (%) years 6 (0.01%)
1915-01-01 to 1915-12-31 overall overall N (%) years 30 (0.04%)
<=20 overall N (%) years 30 (0.04%)
overall Male N (%) years 12 (0.02%)
Female N (%) years 18 (0.03%)
<=20 Female N (%) years 18 (0.03%)
Male N (%) years 12 (0.02%)
1916-01-01 to 1916-12-31 overall overall N (%) years 22 (0.03%)
<=20 overall N (%) years 22 (0.03%)
overall Male N (%) years 8 (0.01%)
Female N (%) years 14 (0.02%)
<=20 Female N (%) years 14 (0.02%)
Male N (%) years 8 (0.01%)
1917-01-01 to 1917-12-31 overall overall N (%) years 25 (0.04%)
<=20 overall N (%) years 25 (0.04%)
overall Male N (%) years 14 (0.02%)
Female N (%) years 11 (0.02%)
<=20 Female N (%) years 11 (0.02%)
Male N (%) years 14 (0.02%)
1918-01-01 to 1918-12-31 overall overall N (%) years 20 (0.03%)
<=20 overall N (%) years 20 (0.03%)
overall Female N (%) years 13 (0.02%)
Male N (%) years 7 (0.01%)
<=20 Female N (%) years 13 (0.02%)
Male N (%) years 7 (0.01%)
1919-01-01 to 1919-12-31 overall overall N (%) years 26 (0.04%)
<=20 overall N (%) years 26 (0.04%)
overall Female N (%) years 13 (0.02%)
Male N (%) years 13 (0.02%)
<=20 Male N (%) years 13 (0.02%)
Female N (%) years 13 (0.02%)
1920-01-01 to 1920-12-31 overall overall N (%) years 28 (0.04%)
<=20 overall N (%) years 28 (0.04%)
overall Female N (%) years 18 (0.03%)
Male N (%) years 10 (0.01%)
<=20 Female N (%) years 18 (0.03%)
Male N (%) years 10 (0.01%)
1921-01-01 to 1921-12-31 overall overall N (%) years 33 (0.05%)
<=20 overall N (%) years 33 (0.05%)
overall Female N (%) years 22 (0.03%)
Male N (%) years 11 (0.02%)
<=20 Female N (%) years 22 (0.03%)
Male N (%) years 11 (0.02%)
1922-01-01 to 1922-12-31 overall overall N (%) years 38 (0.06%)
<=20 overall N (%) years 38 (0.06%)
overall Male N (%) years 18 (0.03%)
Female N (%) years 20 (0.03%)
<=20 Male N (%) years 18 (0.03%)
Female N (%) years 20 (0.03%)
1923-01-01 to 1923-12-31 overall overall N (%) years 39 (0.06%)
<=20 overall N (%) years 39 (0.06%)
overall Male N (%) years 19 (0.03%)
Female N (%) years 20 (0.03%)
<=20 Female N (%) years 20 (0.03%)
Male N (%) years 19 (0.03%)
1924-01-01 to 1924-12-31 overall overall N (%) years 44 (0.06%)
<=20 overall N (%) years 44 (0.06%)
overall Female N (%) years 27 (0.04%)
Male N (%) years 17 (0.03%)
<=20 Female N (%) years 27 (0.04%)
Male N (%) years 17 (0.03%)
1925-01-01 to 1925-12-31 overall overall N (%) years 46 (0.07%)
<=20 overall N (%) years 46 (0.07%)
overall Female N (%) years 31 (0.05%)
Male N (%) years 15 (0.02%)
<=20 Male N (%) years 15 (0.02%)
Female N (%) years 31 (0.05%)
1926-01-01 to 1926-12-31 overall overall N (%) years 50 (0.07%)
<=20 overall N (%) years 50 (0.07%)
overall Female N (%) years 31 (0.05%)
Male N (%) years 19 (0.03%)
<=20 Male N (%) years 19 (0.03%)
Female N (%) years 31 (0.05%)
1927-01-01 to 1927-12-31 overall overall N (%) years 47 (0.07%)
<=20 overall N (%) years 47 (0.07%)
overall Female N (%) years 23 (0.03%)
Male N (%) years 24 (0.04%)
<=20 Male N (%) years 24 (0.04%)
Female N (%) years 23 (0.03%)
1928-01-01 to 1928-12-31 overall overall N (%) years 49 (0.07%)
<=20 overall N (%) years 49 (0.07%)
overall Female N (%) years 32 (0.05%)
Male N (%) years 17 (0.03%)
<=20 Male N (%) years 17 (0.03%)
Female N (%) years 32 (0.05%)
1929-01-01 to 1929-12-31 overall overall N (%) years 32 (0.05%)
<=20 overall N (%) years 32 (0.05%)
overall Female N (%) years 20 (0.03%)
Male N (%) years 12 (0.02%)
<=20 Male N (%) years 12 (0.02%)
Female N (%) years 20 (0.03%)
1930-01-01 to 1930-12-31 overall overall N (%) years 45 (0.07%)
<=20 overall N (%) years 42 (0.06%)
>20 overall N (%) years 3 (0.00%)
overall Male N (%) years 24 (0.04%)
Female N (%) years 21 (0.03%)
<=20 Male N (%) years 24 (0.04%)
Female N (%) years 18 (0.03%)
>20 Female N (%) years 3 (0.00%)
1931-01-01 to 1931-12-31 overall overall N (%) years 52 (0.08%)
>20 overall N (%) years 2 (0.00%)
<=20 overall N (%) years 50 (0.07%)
overall Female N (%) years 31 (0.05%)
Male N (%) years 21 (0.03%)
<=20 Male N (%) years 21 (0.03%)
Female N (%) years 29 (0.04%)
>20 Female N (%) years 2 (0.00%)
1932-01-01 to 1932-12-31 overall overall N (%) years 44 (0.06%)
<=20 overall N (%) years 40 (0.06%)
>20 overall N (%) years 4 (0.01%)
overall Male N (%) years 20 (0.03%)
Female N (%) years 24 (0.04%)
<=20 Male N (%) years 20 (0.03%)
>20 Female N (%) years 4 (0.01%)
<=20 Female N (%) years 20 (0.03%)
1933-01-01 to 1933-12-31 overall overall N (%) years 45 (0.07%)
<=20 overall N (%) years 38 (0.06%)
>20 overall N (%) years 7 (0.01%)
overall Male N (%) years 21 (0.03%)
Female N (%) years 24 (0.04%)
<=20 Male N (%) years 20 (0.03%)
>20 Female N (%) years 6 (0.01%)
<=20 Female N (%) years 18 (0.03%)
>20 Male N (%) years 1 (0.00%)
1934-01-01 to 1934-12-31 overall overall N (%) years 42 (0.06%)
<=20 overall N (%) years 39 (0.06%)
>20 overall N (%) years 3 (0.00%)
overall Female N (%) years 29 (0.04%)
Male N (%) years 13 (0.02%)
>20 Male N (%) years 1 (0.00%)
<=20 Female N (%) years 27 (0.04%)
>20 Female N (%) years 2 (0.00%)
<=20 Male N (%) years 12 (0.02%)
1935-01-01 to 1935-12-31 overall overall N (%) years 53 (0.08%)
>20 overall N (%) years 15 (0.02%)
<=20 overall N (%) years 38 (0.06%)
overall Female N (%) years 23 (0.03%)
Male N (%) years 30 (0.04%)
>20 Male N (%) years 6 (0.01%)
<=20 Male N (%) years 24 (0.04%)
Female N (%) years 14 (0.02%)
>20 Female N (%) years 9 (0.01%)
1936-01-01 to 1936-12-31 overall overall N (%) years 69 (0.10%)
>20 overall N (%) years 11 (0.02%)
<=20 overall N (%) years 58 (0.09%)
overall Male N (%) years 27 (0.04%)
Female N (%) years 42 (0.06%)
>20 Female N (%) years 8 (0.01%)
<=20 Female N (%) years 34 (0.05%)
Male N (%) years 24 (0.04%)
>20 Male N (%) years 3 (0.00%)
1937-01-01 to 1937-12-31 overall overall N (%) years 68 (0.10%)